@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -29,19 +29,17 @@ package com.sun.interview;
 import java.net.URL;
 import java.text.MessageFormat;
 import java.util.Map;
-import javax.help.HelpSet;
-import javax.help.Map.ID;
 
 /**
  * Questions are the primary constituent elements of {@link Interview interviews}.
- * They provide text and an optional graphic to be presented to the user, 
+ * They provide text and an optional graphic to be presented to the user,
  * and they provide a place to store the user's response.
- * Various subtypes are provided, according to the type of response they 
+ * Various subtypes are provided, according to the type of response they
  * request and store.
  * Questions are identified internally by a unique tag, which is used to identify
  * the question in contexts such as resource bundles, dictionaries, and so on.
  */
-public abstract class Question 
+public abstract class Question
 {
 
     /**
@@ -50,22 +48,22 @@ public abstract class Question
      * @param baseTag A name to uniquely identify this question within its interview.
      */
     protected Question(Interview interview, String baseTag) {
-	if (baseTag == null || baseTag.length() == 0)
-	    throw new IllegalArgumentException("No tag specified");
+        if (baseTag == null || baseTag.length() == 0)
+            throw new IllegalArgumentException("No tag specified");
 
-	this.interview = interview;
-	this.baseTag = baseTag;
+        this.interview = interview;
+        this.baseTag = baseTag;
 
-	updateTag();
+        updateTag();
 
-	interview.add(this);
+        interview.add(this);
 
-	String c = interview.getClass().getName();
-	int dot = c.lastIndexOf(".");
-	if (dot != -1)
-	    c = c.substring(dot+1);
-	c = c.replace('$', '.');
-	key = c + "." + baseTag;
+        String c = interview.getClass().getName();
+        int dot = c.lastIndexOf(".");
+        if (dot != -1)
+            c = c.substring(dot+1);
+        c = c.replace('$', '.');
+        key = c + "." + baseTag;
     }
 
     /**
@@ -73,10 +71,10 @@ public abstract class Question
      * @param interview The interview containing this question.
      */
     protected Question(Interview interview) {
-	this.interview = interview;
-	baseTag = null;
-	tag = null;
-	key = null;
+        this.interview = interview;
+        baseTag = null;
+        tag = null;
+        key = null;
     }
 
     /**
@@ -84,7 +82,7 @@ public abstract class Question
      * @return the interview of which this question is a part
      */
     public Interview getInterview() {
-	return interview;
+        return interview;
     }
 
     /**
@@ -98,7 +96,7 @@ public abstract class Question
      * @see #getTag
      */
     public String getKey() {
-	return key;
+        return key;
     }
 
     /**
@@ -111,29 +109,29 @@ public abstract class Question
      * @see #getKey
      */
     public String getTag() {
-	return tag;
+        return tag;
     }
 
     String getBaseTag() {
-	return baseTag;
+        return baseTag;
     }
 
     void updateTag() {
-	if (interview.getTag() == null)
-	    tag = baseTag;
-	else
-	    tag = (interview.getTag() + "." + baseTag);
+        if (interview.getTag() == null)
+            tag = baseTag;
+        else
+            tag = (interview.getTag() + "." + baseTag);
     }
 
     /**
      * Set the text for this question. The text can also be provided
-     * in the containing interview's resource bundle, using the resource name 
+     * in the containing interview's resource bundle, using the resource name
      * <i>key</i>.<code>text</code>.
      * @param text the text for this question
      * @see #getText
      */
     protected void setText(String text) {
-	this.text = text.trim();
+        this.text = text.trim();
     }
 
     /**
@@ -144,17 +142,17 @@ public abstract class Question
      * @see #setText
      */
     public String getText() {
-	if (text == null) {
-	    text = getResourceString(interview, key + ".text", true);
-	    if (text == null) 
-		text = key + ".text";
-	}
-	return MessageFormat.format(text, getTextArgs());
+        if (text == null) {
+            text = getResourceString(interview, key + ".text", true);
+            if (text == null)
+                text = key + ".text";
+        }
+        return MessageFormat.format(text, getTextArgs());
     }
 
     /**
      * Get any arguments necessary to go with the question text.
-     * The text is formatted using the rules specified for 
+     * The text is formatted using the rules specified for
      * {@link java.text.MessageFormat#format}. By default, this
      * method returns null. If the text for the question contains
      * variable entries (using the '{' '}' notation), you should
@@ -163,18 +161,18 @@ public abstract class Question
      * of the question.
      */
     protected Object[] getTextArgs() {
-	return null;
+        return null;
     }
 
     /**
      * Set the summary text for this question. The text can also be provided
-     * in the containing interview's resource bundle, using the resource name 
+     * in the containing interview's resource bundle, using the resource name
      * <i>key</i>.<code>smry</code>.
      * @param summary a short summary of the text for this question
      * @see #getSummary
      */
     protected void setSummary(String summary) {
-	this.summary = summary.trim();
+        this.summary = summary.trim();
     }
 
     /**
@@ -183,33 +181,33 @@ public abstract class Question
      * @see #setSummary
      */
     public String getSummary() {
-	if (summary == null) {
-	    summary = getResourceString(interview, key + ".smry", true);
-	    if (summary == null)
-		summary = key + ".smry";
-	    /* OLD, undocumented and mildly suspect (e.g. i18n)
-	    if (summary == null) {
-		// search text for either a newline, or for whitespace
-		// following a .
-		String t = getText();
-		if (t != null) {
-		    for (int i = 0; i < t.length(); i++) {
-			char c = t.charAt(i);
-			if (c == '\n' 
-			    || (Character.isWhitespace(c) 
-				&& i > 0 
-				&& t.charAt(i-1) == '.' )) {
-			    summary = t.substring(0, i).trim();
-			    break;
-			}
-		    }
-		    if (summary == null)
-			summary = t;
-		}
-	    }
-	    */
-	}
-	return summary;
+        if (summary == null) {
+            summary = getResourceString(interview, key + ".smry", true);
+            if (summary == null)
+                summary = key + ".smry";
+            /* OLD, undocumented and mildly suspect (e.g. i18n)
+            if (summary == null) {
+                // search text for either a newline, or for whitespace
+                // following a .
+                String t = getText();
+                if (t != null) {
+                    for (int i = 0; i < t.length(); i++) {
+                        char c = t.charAt(i);
+                        if (c == '\n'
+                            || (Character.isWhitespace(c)
+                                && i > 0
+                                && t.charAt(i-1) == '.' )) {
+                            summary = t.substring(0, i).trim();
+                            break;
+                        }
+                    }
+                    if (summary == null)
+                        summary = t;
+                }
+            }
+            */
+        }
+        return summary;
     }
 
     /**
@@ -219,7 +217,7 @@ public abstract class Question
      * @see #getImage
      */
     public void setImage(String resource) {
-	image = Question.class.getResource(resource);
+        image = Question.class.getResource(resource);
     }
 
     /**
@@ -229,62 +227,52 @@ public abstract class Question
      * @see #getImage
      */
     protected void setImage(URL u) {
-	image = u;
+        image = u;
     }
 
     /**
      * Get the graphic for this question. If {@link #setImage}
      * has been called to supply a specific image for this question,
      * that will be the result here; otherwise, the value defaults
-     * first to a question-specific resource (<i>tag</i><code>.gif</code>) 
+     * first to a question-specific resource (<i>tag</i><code>.gif</code>)
      * and then to a {@link Interview#getDefaultImage default image}
      * for the interview.
      * @return a URL for the question.
      * @see #setImage
      */
     public URL getImage() {
-	if (image == null)
-	    image = getClass().getResource(tag + ".gif");
-	if (image == null)
-	    image = interview.getDefaultImage();
-	return image;
+        if (image == null)
+            image = getClass().getResource(tag + ".gif");
+        if (image == null)
+            image = interview.getDefaultImage();
+        return image;
     }
 
     /**
      * Get the JavaHelp ID identifying the "more info" help for this
      * question, or null if none.
+     *
+     * Normally, this method returns null and real work on JavaHelp ID is done
+     * by com.sun.interview.wizard.Help class, if wizard presents.
+     * Subclasses might override this method to return not null value,
+     * in this case returned value will be used. Returned object must be
+     * an instance of javax.help.Map.ID.
+     *
      * @return the JavaHelp ID identifying the "more info" help for this
      * question, or null if none.
      */
-    public ID getHelpID() {
-	if (id == null) 
-	    id = getID(interview, key);
-	return id;
+    public Object getHelpID() {
+        return helpID;
     }
 
-    private ID getID(Interview i, String key) {
-	//System.err.println("Q: int:" + i.getTag() + " key:" + key);
-	ID id = null;
-	if (i.getParent() != null)
-	    id = getID(i.getParent(), key);
-	
-	if (id != null) {
-	    //System.err.println("Q: int:" + i.getTag() + " key:" + key + " id:" + id);
-	    return id;
-	}
-	
-	HelpSet hs = i.getHelpSet();
-	if (hs != null) {
-	    javax.help.Map m = hs.getLocalMap();
-	    if (m != null && m.isValidID(key, hs)) {
-		id = ID.create(key, hs);
-		//System.err.println("Q: FOUND int:" + i.getTag() + " key:" + key + " id:" + id);
-		return id;
-	    }
-	}
-	    
-	//System.err.println("Q: int:" + i.getTag() + " key:" + key + " id:<null>");
-	return null;
+    /**
+     * Set HelpID object associated with the Question.
+     *
+     * @param object Should be instance of javax.help.Map.ID
+     *
+     */
+    public void setHelpID(Object object) {
+        helpID = object;
     }
 
     /**
@@ -300,35 +288,35 @@ public abstract class Question
 
     /**
      * Add a named marker to this question, if it has not already been added.
-     * @param name the name of the marker to be added. 
+     * @param name the name of the marker to be added.
      * @throws NullPointerException if name is null
      */
     public void addMarker(String name) {
-	interview.addMarker(this, name);
+        interview.addMarker(this, name);
     }
 
     /**
      * Remove a named marker to this question.
-     * @param name the name of the marker to be removed. 
+     * @param name the name of the marker to be removed.
      */
     public void removeMarker(String name) {
-	interview.removeMarker(this, name);
+        interview.removeMarker(this, name);
     }
 
     /**
      * Check if a marker has been added to this question.
-     * @param name the name of the marker to be checked. 
+     * @param name the name of the marker to be checked.
      * @return true if the marker has been added to this question, and false otherwise.
      */
     public boolean hasMarker(String name) {
-	return interview.hasMarker(this, name);
+        return interview.hasMarker(this, name);
     }
 
 
     /**
      * Determine if this question is currently "hidden".
      * Hidden questions do not appear on the current path
-     * and so are skipped over by {@link Interview#prev} and 
+     * and so are skipped over by {@link Interview#prev} and
      * {@link Interview#next}, etc.
      * By default, questions are not hidden, and this method returns false.
      * Override this method if you want to hide a question - note that the
@@ -336,21 +324,21 @@ public abstract class Question
      * this method.  Developers who wish to independently play with hiding and
      * enabling should override both methods.
      * @since 4.3
-     * @return true if this question has been hidden. 
+     * @return true if this question has been hidden.
      * @see Question#isEnabled
      */
     public boolean isHidden() {
-	return false;
+        return false;
     }
 
 
     /**
-     * Determine if this question is currently enabled. 
+     * Determine if this question is currently enabled.
      * Disabled questions do not appear on the current path
-     * and so are skipped over by {@link Interview#prev} and 
+     * and so are skipped over by {@link Interview#prev} and
      * {@link Interview#next}, etc.
      * By default, all questions are enabled, and this method returns true.
-     * Override this method if you want to hide a question. 
+     * Override this method if you want to hide a question.
      * It can be convenient to determine whether or not a question should be
      * disabled by using the values of earlier questions.
      * <em>Note:</em> for backwards compatibility, the default implementation
@@ -359,11 +347,11 @@ public abstract class Question
      * and false otherwise.
      */
     public boolean isEnabled() {
-	return (!isHidden());
+        return (!isHidden());
     }
 
     /**
-     * Get the next question to be asked. 
+     * Get the next question to be asked.
      * @return the next question to be asked
      */
     protected abstract Question getNext();
@@ -409,14 +397,14 @@ public abstract class Question
     public abstract boolean isValueAlwaysValid();
 
     /**
-     * Load any state for this question from a dictionary, 
+     * Load any state for this question from a dictionary,
      * using the tag as the key.
      * @param data The map from which to load the value for this question.
      */
     protected abstract void load(Map data);
 
     /**
-     * Save any state for this question in a dictionary, 
+     * Save any state for this question in a dictionary,
      * using the tag as the key.
      * @param data The map in which to save the value for this question.
      */
@@ -450,24 +438,24 @@ public abstract class Question
 
     /**
      * Check if this question equals another.
-     * By default, two questions are equal if they have equal tags, 
+     * By default, two questions are equal if they have equal tags,
      * and the string values are either both null
      * or are equal.
      */
     public boolean equals(Object other) {
         if (this == other)
             return true;
-        
-	if ( !(other instanceof Question))
-	    return false;
 
-	Question oq = (Question) other;
+        if ( !(other instanceof Question))
+            return false;
 
-	return (equal(tag, oq.tag) && equal(getStringValue(), oq.getStringValue()));
+        Question oq = (Question) other;
+
+        return (equal(tag, oq.tag) && equal(getStringValue(), oq.getStringValue()));
     }
 
     private static boolean equal(String s1, String s2) {
-	return (s1 == null || s2 == null ? s1 == s2 : s1.equals(s2));
+        return (s1 == null || s2 == null ? s1 == s2 : s1.equals(s2));
     }
 
     public int hashCode()  {
@@ -475,11 +463,11 @@ public abstract class Question
         hash = 31 * hash + (null == tag ? 0 : tag.hashCode());
         String str_val = getStringValue();
         hash = 31 * hash + (null == str_val ? 0 : str_val.hashCode());
-        
+
         return hash;
     }
     /**
-     * Get an entry from the interview's resource bundle. 
+     * Get an entry from the interview's resource bundle.
      * The parent and other ancestors bundles will be checked first before
      * this interview's bundle, allowing the root interview a chance to override
      * the default value provided by this interview.
@@ -488,7 +476,7 @@ public abstract class Question
      * @see Interview#getResourceString(String)
      */
     protected String getResourceString(String key) {
-	return interview.getResourceString(key);
+        return interview.getResourceString(key);
     }
 
     /**
@@ -505,41 +493,41 @@ public abstract class Question
      * @see Interview#getResourceString(String, boolean)
      */
     protected String getResourceString(String key, boolean checkAncestorsFirst) {
-	return interview.getResourceString(key, checkAncestorsFirst);
+        return interview.getResourceString(key, checkAncestorsFirst);
     }
 
     private String getResourceString(Interview interview, String key, boolean checkAncestorsFirst) {
-	return interview.getResourceString(key, checkAncestorsFirst);
-	/*
-	 * the following code is now in Interview.getResourceString
-	try {
-	    //System.err.println("QU: " + interview.getTag() + " " + key);
-	    String s = null;
-	    Interview p = interview.getParent();
-	    if (checkAncestorsFirst) {
-		if (p != null)
-		    s = getResourceString(p, key, checkAncestorsFirst);
-		if (s == null) {
-		    ResourceBundle b = interview.getResourceBundle();
-		    if (b != null)
-			s = b.getString(key);
-		}
-	    }
-	    else {
-		ResourceBundle b = interview.getResourceBundle();
-		if (b != null)
-		    s = b.getString(key);
-		if (s == null && p != null)
-		    s = getResourceString(p, key, checkAncestorsFirst);
-	    }
-	    //System.err.println("QU: " + interview.getTag() + " " + key + " " + s);
-	    return s;
-	}
-	catch (MissingResourceException e) {
-	    //System.err.println("QU: " + interview.getTag() + " " + key + " -null-");
-	    return null;
-	}
-	*/
+        return interview.getResourceString(key, checkAncestorsFirst);
+        /*
+         * the following code is now in Interview.getResourceString
+        try {
+            //System.err.println("QU: " + interview.getTag() + " " + key);
+            String s = null;
+            Interview p = interview.getParent();
+            if (checkAncestorsFirst) {
+                if (p != null)
+                    s = getResourceString(p, key, checkAncestorsFirst);
+                if (s == null) {
+                    ResourceBundle b = interview.getResourceBundle();
+                    if (b != null)
+                        s = b.getString(key);
+                }
+            }
+            else {
+                ResourceBundle b = interview.getResourceBundle();
+                if (b != null)
+                    s = b.getString(key);
+                if (s == null && p != null)
+                    s = getResourceString(p, key, checkAncestorsFirst);
+            }
+            //System.err.println("QU: " + interview.getTag() + " " + key + " " + s);
+            return s;
+        }
+        catch (MissingResourceException e) {
+            //System.err.println("QU: " + interview.getTag() + " " + key + " -null-");
+            return null;
+        }
+        */
     }
 
     /**
@@ -548,14 +536,14 @@ public abstract class Question
     protected Interview interview;
 
     /**
-     * A unique tag to identify this question. 
+     * A unique tag to identify this question.
      */
     protected String tag; // parent tag + baseTag
 
     private String baseTag; // tag relative to parent
 
     /**
-     * A unique key to identify the resources for this question. 
+     * A unique key to identify the resources for this question.
      */
     protected final String key;
 
@@ -571,7 +559,7 @@ public abstract class Question
 
     /**
      */
-    private ID id;
+    private Object helpID;
 
     /**
      * A URL for a graphic for this question.
