@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2001, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2001, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -179,13 +179,13 @@ public abstract class InterviewParameters
 
     /**
      *  The template manager is used to change behavior of
-     *  template saving, the default implementation is 
+     *  template saving, the default implementation is
      *  the context manager of corresponding test suite.
      */
     public interface TemplateManager {
         /**
          * This method is invoked each time before saving template.
-         * The template will be saved only if this method returns true. 
+         * The template will be saved only if this method returns true.
          * @param file template file
          * @return true if this operation is allowed, false otherwise
          */
@@ -236,7 +236,7 @@ public abstract class InterviewParameters
      * This method is called when the object is created
      * from an entry in a .jtt file.
      * By default, the method throws an exception if any arguments
-     * are given. It should be redefined by any test suites that wish 
+     * are given. It should be redefined by any test suites that wish
      * to support this type of initialization.
      * @param args test suite specific args with which to initialize
      * this InterviewParameters object
@@ -256,7 +256,18 @@ public abstract class InterviewParameters
      * Any following invocations on this object may result in unpredictable
      * exceptions because of object inconsistence.
      */
-    public void dispose() {}
+    public void dispose() {
+        kflFiles = null;
+        backupPolicy = null;
+        cachedExcludeListFilter = null;
+        cachedKeywordsFilter = null;
+        cachedRelevantTestFilter = null;
+        cachedRelevantTestFilterEnv = null;
+        cachedStatusFilter = null;
+        cachedTestFilters = null;
+        pc = null;
+        templateManager = null;
+    }
 
     //----------------------------------------------------------------------------
 
@@ -267,7 +278,7 @@ public abstract class InterviewParameters
      * may need to be evaluated to get the required value. Subtypes may
      * choose to override this method to provide a more efficient
      * implementation.
-     * 
+     *
      * <p> Since the default implementation gets the name from the test
      * environment, clients should not use this method to determine
      * the name for the test environment, unless this method is redefined.
@@ -302,8 +313,8 @@ public abstract class InterviewParameters
     /**
      * Get a description for this configuration.
      * By default and for backwards compatibility, this defaults to the
-     * description entry in the test environment, which means that the 
-     * whole environment may need to be evaluated to get the required value. 
+     * description entry in the test environment, which means that the
+     * whole environment may need to be evaluated to get the required value.
      * Subtypes may choose to override this method to provide a more efficient
      * implementation.
      * @return a description for this configuration, or null if not known
@@ -323,7 +334,7 @@ public abstract class InterviewParameters
 
     /**
      * Get the next question to the asked after the initial prolog
-     * of questions. 
+     * of questions.
      * The default value is the result of getEnvFirstQuestion.
      * @return the next question to be asked after the initial prolog
      * of questions.
@@ -346,7 +357,7 @@ public abstract class InterviewParameters
 
     /**
      * Get the first question to be asked concerning the environment to be
-     * set up and used for each test to be run. If these questions are 
+     * set up and used for each test to be run. If these questions are
      * contained in an interview, this method can be simply implemented as:<br>
      *  <code>return callInterview(</code><i>envInterview</i><code>, getEnvSuccessorQuestion);</code><br>
      * @return the first question to be asked concerning the environment to be
@@ -356,11 +367,11 @@ public abstract class InterviewParameters
     protected abstract Question getEnvFirstQuestion();
 
     /**
-     * Get the next question to be asked after those concerning 
-     * the environment to be set up and used for each test to be run. 
+     * Get the next question to be asked after those concerning
+     * the environment to be set up and used for each test to be run.
      * The default value is the result of getTestsFirstQuestion.
-     * @return the next question to be asked after those concerning 
-     * the environment to be set up and used for each test to be run. 
+     * @return the next question to be asked after those concerning
+     * the environment to be set up and used for each test to be run.
      * @see #getEnvFirstQuestion
      */
     protected Question getEnvSuccessorQuestion() {
@@ -443,7 +454,7 @@ public abstract class InterviewParameters
      * field, which subclasses may set.
      * @since 4.4
      * @see #setKnownFailureFiles(java.io.File[])
-     * @return The list of known failure list files.
+     * @return The list of known failure list files.  Null if none.
      */
     public File[] getKnownFailureFiles() {
         return kflFiles;
@@ -471,10 +482,10 @@ public abstract class InterviewParameters
     }
 
     /**
-     * Get the next question to be asked after those concerning 
+     * Get the next question to be asked after those concerning
      * the exclude list to be used to exclude tests from the test run.
      * The default value is the result of getKeywordsFirstQuestion,
-     * @return the next question to be asked after those concerning 
+     * @return the next question to be asked after those concerning
      * the exclude list to be used to exclude tests from the test run.
      * @see #getExcludeListFirstQuestion
      */
@@ -483,9 +494,9 @@ public abstract class InterviewParameters
     }
 
     /**
-     * Get the next question to be asked after those concerning 
+     * Get the next question to be asked after those concerning
      * the exclude list to be used to exclude tests from the test run.
-     * @return the next question to be asked after those concerning 
+     * @return the next question to be asked after those concerning
      * the exclude list to be used to exclude tests from the test run
      * @deprecated Use getExcludeListFirstQuestion().
      * @see #getExcludeListSuccessorQuestion
@@ -509,10 +520,10 @@ public abstract class InterviewParameters
     protected abstract Question getKeywordsFirstQuestion();
 
     /**
-     * Get the next question to be asked after those concerning 
+     * Get the next question to be asked after those concerning
      * the keywords that may be used to select tests for the test run.
      * The default value is the result of getPriorStatusQuestion.
-     * @return the next question to be asked after those concerning 
+     * @return the next question to be asked after those concerning
      * the keywords that may be used to select tests for the test run.
      * @see #getKeywordsFirstQuestion
      */
@@ -535,13 +546,13 @@ public abstract class InterviewParameters
     protected abstract Question getPriorStatusFirstQuestion();
 
     /**
-     * Get the next question to be asked after those concerning 
-     * whether tests should be selected for execution according to their 
+     * Get the next question to be asked after those concerning
+     * whether tests should be selected for execution according to their
      * prior execution status.
      * The default value is the result of getConcurrencyFirstQuestion
-     * @return the next question to be asked after those concerning 
-     * whether tests should be selected for execution according to their 
-     * prior execution status. 
+     * @return the next question to be asked after those concerning
+     * whether tests should be selected for execution according to their
+     * prior execution status.
      * @see #getPriorStatusFirstQuestion
      */
     protected Question getPriorStatusSuccessorQuestion() {
@@ -563,10 +574,10 @@ public abstract class InterviewParameters
     protected abstract Question getConcurrencyFirstQuestion();
 
     /**
-     * Get the next question after those concerning the number 
+     * Get the next question after those concerning the number
      * of tests that may be run in parallel.
      * The default is the result of getTimeoutFactorFirstQuestion
-     * @return the next question after those concerning the number 
+     * @return the next question after those concerning the number
      * of tests that may be run in parallel.
      * @see #getConcurrencyFirstQuestion
      */
@@ -614,7 +625,7 @@ public abstract class InterviewParameters
     /**
      * Determine whether all the configuration values are valid, by
      * checking if the interview has been completed.
-     * If so, the result will be true; if not, the result will be false, 
+     * If so, the result will be true; if not, the result will be false,
      * and getErrorMessage will provide details about at least one of the
      * invalid values.
      * @return true if and only if all the configuration values are valid
@@ -795,7 +806,7 @@ public abstract class InterviewParameters
 
     /**
      * Determine if the current instance is a template or not.
-     * @return true if the current instance is a template, 
+     * @return true if the current instance is a template,
      * and false otherwise
      */
     public boolean isTemplate() {
@@ -852,7 +863,7 @@ public abstract class InterviewParameters
 
 
     /**
-     * Get the file associated with this interview. 
+     * Get the file associated with this interview.
      * @return the file associated with this interview.
      * @see #setFile
      * @see #load
@@ -878,7 +889,7 @@ public abstract class InterviewParameters
         }
         else {
             // means: unknown; will likely a trigger a reload
-            currFileLastModified = 0; 
+            currFileLastModified = 0;
         }
     }
 
@@ -886,7 +897,7 @@ public abstract class InterviewParameters
      * Determine if the specified file is an interview file,
      * as determined by whether its extension is .jti or not.
      * @param f the file to be checked
-     * @return true if the specified file is an interview file, 
+     * @return true if the specified file is an interview file,
      * and false otherwise
      */
     public static boolean isInterviewFile(File f) {
@@ -900,7 +911,7 @@ public abstract class InterviewParameters
      * @return an InterviewParameters as determined by the contents of an
      * interview file.
      * @throws IOException is there is a problem reading the file
-     * @throws Interview.Fault if there is a problem instantiating the 
+     * @throws Interview.Fault if there is a problem instantiating the
      * interview
      */
     public static InterviewParameters open(File file)
@@ -917,7 +928,7 @@ public abstract class InterviewParameters
      * @return an InterviewParameters as determined by the test suite
      * and the contents of an interview file
      * @throws IOException is there is a problem reading the file
-     * @throws Interview.Fault if there is a problem instantiating the 
+     * @throws Interview.Fault if there is a problem instantiating the
      * interview
      */
     public static InterviewParameters open(File file, TestSuite testSuite)
@@ -933,12 +944,12 @@ public abstract class InterviewParameters
      * Create an InterviewParameters by populating the interview for a specified
      * work directory with responses from a given file.
      * @param file the file to be read
-     * @param workDir the work directory (implying the test suite) for which 
+     * @param workDir the work directory (implying the test suite) for which
      * to create the interview
      * @return an InterviewParameters as determined by the work directory
      * and the contents of an interview file
      * @throws IOException is there is a problem reading the file
-     * @throws Interview.Fault if there is a problem instantiating the 
+     * @throws Interview.Fault if there is a problem instantiating the
      * interview
      */
     public static InterviewParameters open(File file, WorkDirectory workDir)
@@ -1069,7 +1080,7 @@ public abstract class InterviewParameters
      * test suite and work directory. Any, but not all, of these paths may be null.
      * Any non-null path must specify an appropriate existing file, otherwise
      * an exception will be thrown.
-     * @param testSuitePath the path for the test suite; if not specified, 
+     * @param testSuitePath the path for the test suite; if not specified,
      * the test suite will default from the work directory (if specified) or
      * the configuration file.
      * @param workDirPath the path for the work directory; if not specified,
@@ -1098,7 +1109,7 @@ public abstract class InterviewParameters
      * test suite and work directory. Any, but not all, of these paths may be null.
      * Any non-null path must specify an appropriate existing file, otherwise
      * an exception will be thrown.
-     * @param testSuitePath the path for the test suite; if not specified, 
+     * @param testSuitePath the path for the test suite; if not specified,
      * the test suite will default from the work directory (if specified) or
      * the configuration file.
      * @param workDirPath the path for the work directory; if not specified,
@@ -1223,11 +1234,11 @@ public abstract class InterviewParameters
 
 
     /**
-     * Load the interview with the contents of the file associated with 
-     * the interview. If the file does not exist, the interview will be 
+     * Load the interview with the contents of the file associated with
+     * the interview. If the file does not exist, the interview will be
      * cleared.
      * @throws IOException is there is a problem reading the file
-     * @throws Interview.Fault if there is a problem loading the 
+     * @throws Interview.Fault if there is a problem loading the
      * interview
      * @return true if there was an update from template
      */
@@ -1248,7 +1259,7 @@ public abstract class InterviewParameters
      * @param file the file to be loaded
      * @throws FileNotFoundException if the specified file does not exist.
      * @throws IOException is there is a problem reading the file
-     * @throws Interview.Fault if there is a problem loading the 
+     * @throws Interview.Fault if there is a problem loading the
      * interview
      * @return true if there was an update from template
      */
@@ -1317,7 +1328,7 @@ public abstract class InterviewParameters
 
     /**
      * Load the interview as best as possible with the data in another
-     * Parameters object. If any of the various sub-objects as returned by 
+     * Parameters object. If any of the various sub-objects as returned by
      * get<i>XXX</i>Parameters are not recognized, they will be ignored.
      * @param other The Parameters object to be copied.
      */
@@ -1467,7 +1478,7 @@ public abstract class InterviewParameters
      * Save the current set of answers for the interview in the standard
      * file associated with the interview.
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      * @see #getFile
      */
@@ -1484,7 +1495,7 @@ public abstract class InterviewParameters
      * and make that file the new file associated with the interview.
      * @param file the file in which to save the state of the interview
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      * @see #getFile
      */
@@ -1500,7 +1511,7 @@ public abstract class InterviewParameters
      * @param file the file in which to save the state of the interview
      * @param isTemplate
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      * @see #getFile
      */
@@ -1519,7 +1530,7 @@ public abstract class InterviewParameters
      * including the paths for the test suite and work directory.
      * @param file the file in which to save the state of the interview
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      */
     public void saveAs(File file)
@@ -1540,7 +1551,7 @@ public abstract class InterviewParameters
      * in the file.
      * @param isTemplate True, the interview will be saved as template.
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      */
     public void saveAs(File file, boolean saveTestSuite, boolean saveWorkDir, boolean isTemplate)
@@ -1596,7 +1607,7 @@ public abstract class InterviewParameters
      * @param saveWorkDir if true, the work directory path will be saved
      * in the file.
      * @throws IOException is there is a problem writing the file
-     * @throws Interview.Fault if there is a problem preparing the 
+     * @throws Interview.Fault if there is a problem preparing the
      * interview to be written
      */
     public void saveAs(File file, boolean saveTestSuite, boolean saveWorkDir)
@@ -1657,7 +1668,7 @@ public abstract class InterviewParameters
      * Check if the current file has been loaded into this interview,
      * or if the interview has been saved in it.
      * @return true if the file associated with the interview was set as a
-     * side effect of load or save, or false if the file was just set by 
+     * side effect of load or save, or false if the file was just set by
      * setFile.
      */
     public boolean isFileLoaded() {
@@ -1667,7 +1678,7 @@ public abstract class InterviewParameters
     /**
      * Determine if the file associated with this interview has been modified
      * on disk after the last call of load or save.
-     * @return true if the file on disk has been modified after it was last 
+     * @return true if the file on disk has been modified after it was last
      * used by load or save.
      * @see #load()
      * @see #save()
