@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -46,8 +46,6 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import java.util.logging.Handler;
 import java.util.logging.LogRecord;
-import javax.help.HelpSet;
-import javax.help.HelpSetException;
 import com.sun.javatest.finder.BinaryTestFinder;
 import com.sun.javatest.finder.HTMLTestFinder;
 import com.sun.javatest.interview.LegacyParameters;
@@ -56,10 +54,12 @@ import com.sun.javatest.logging.WorkDirLogHandler;
 import com.sun.javatest.logging.ObservedFile;
 import com.sun.javatest.services.ServiceManager;
 import com.sun.javatest.services.ServiceReader;
-import com.sun.javatest.services.XMLServiceReader;
+import com.sun.javatest.services.PropertyServiceReader;
 import com.sun.javatest.util.BackupPolicy;
 import com.sun.javatest.util.I18NResourceBundle;
 import com.sun.javatest.util.StringArray;
+import java.lang.reflect.Method;
+import java.lang.reflect.Modifier;
 
 /**
  * A class providing information about and access to the tests in a test suite.
@@ -938,43 +938,6 @@ public class TestSuite
         return (u != null);
     }
 
-    /**
-     * Get helpsets containing any related documents for this test suite.
-     * By default, the resource names for the help sets are obtained from
-     * getAdditionalDocNames().
-     * @return an array of help sets containing docs associated with this
-     * testsuite. The array will be empty if there are no such docs.
-     * @throws TestSuite.Fault if there are problems opening any of the
-     * helpsets.
-     */
-    public HelpSet[] getAdditionalDocs() throws Fault {
-        if (additionalDocs == null) {
-            String[] names = getAdditionalDocNames();
-            if (names == null)
-               additionalDocs = new HelpSet[0];
-            else {
-                HelpSet[] docs = new HelpSet[names.length];
-                for (int i = 0; i < names.length; i++) {
-                    String name = names[i];
-                    URL u = HelpSet.findHelpSet(loader, name);
-                    if (u == null)
-                        throw new Fault(i18n, "ts.cantFindDoc", name);
-                    try {
-                        docs[i] = new HelpSet(loader, u);
-                    }
-                    catch (HelpSetException e) {
-                        throw new Fault(i18n, "ts.cantOpenDoc",
-                                        new Object[] { name, e });
-                    }
-                }
-                // only set if all opened OK
-                additionalDocs = docs;
-            }
-        }
-
-        return additionalDocs;
-    }
-
     /**
      * Get the names of any helpsets containing related documents for this
      * test suite. The names should identify JavaHelp helpset files, as
@@ -988,7 +951,7 @@ public class TestSuite
      * documents for this testsuite. The result may be null if there are no
      * such documents.
      */
-    protected String[] getAdditionalDocNames() {
+    public String[] getAdditionalDocNames() {
         return (tsInfo == null
                 ? null
                 : StringArray.split((String) (tsInfo.get("additionalDocs"))));
@@ -1173,44 +1136,62 @@ public class TestSuite
     public ClassLoader getClassLoader() {
         return loader;
     }
-    
+
     public ServiceManager getServiceManager() {
         if (!needServices()) {
             return null;
         }
-        
+
         if (serviceManager == null) {
             serviceManager = new ServiceManager(this);
         }
-        
+
         return serviceManager;
     }
-    
+
+    /**
+     * Checks if serviceReader is active and file with service description does
+     * exist.
+     * @return true, if it's needed to start services, false otherwise.
+     */
     public boolean needServices() {
-        String entry = (tsInfo == null ? null : (String) (tsInfo.get("serviceReader")));
-        if (entry != null) {
-            return true;
+        ServiceReader sr = getServiceReader();
+        if (sr == null) {
+            return false;
         }
-        
-        File defs = new File(getRootDir(), XMLServiceReader.SERVICES_XML);
-        
-        return defs.exists();
+
+        /*
+         * Since jt4.5 the ServiceReader has been extended with a new method.
+         * To preserve ability to use new javatest with old test suites
+         * the extra check is performed: check if the newly introduced method
+         * is abstract or not.
+         */
+        boolean isLegacy = false;
+        try {
+            Method m = sr.getClass().getMethod("getServiceDescriptorFileName", new Class[0]);
+            if (Modifier.isAbstract(m.getModifiers())) {
+                isLegacy = true;
+            }
+        } catch (NoSuchMethodException e) {
+             isLegacy = true;
+        }
+        File descrFile = isLegacy ?
+            new File(getRootDir(), File.separator + "lib" + File.separator + "services.xml") :
+            new File(getRootDir(), sr.getServiceDescriptorFileName());
+
+        return descrFile.exists();
     }
     /**
      * Returns a test suite specific ServiceReader, used to read Service
      * definitions.
-     * 
-     * @return ServiceReader instance. Default is XMLServiceReader
+     *
+     * @return ServiceReader instance. Default is PropertyServiceReader
      */
     public ServiceReader getServiceReader() {
-        if (!needServices()) {
-            return null;
-        }
-        
         if (serviceReader != null) {
             return serviceReader;
         }
-        
+
         String servInfo = (String)tsInfo.get("serviceReader");
         if (servInfo != null) {
             String[] args = servInfo.split(" ");
@@ -1223,7 +1204,7 @@ public class TestSuite
                     for (int i = 1; i < args.length; i++) {
                         copy[i-1] = args[i];
                     }
-                    
+
                     serviceReader.init(this, copy);
                 }
                 else {
@@ -1234,13 +1215,13 @@ public class TestSuite
             }
         }
         else {
-            serviceReader = new XMLServiceReader();
+            serviceReader = new PropertyServiceReader();
             serviceReader.init(this, null);
         }
-        
+
         return serviceReader;
     }
-    
+
     /**
      * Get a map containing the test suite data in the .jtt file.
      * @return a map containing the test suite data in the .jtt file
@@ -1283,7 +1264,7 @@ public class TestSuite
 
 
     /**
-     * Returns notification logger associated with 
+     * Returns notification logger associated with
      * given working directory or common logger if null was specified
      * @param wd - working directory or null
      */
@@ -1509,9 +1490,8 @@ public class TestSuite
     private Class scriptClass;
     private String[] scriptArgs;
 
-    private HelpSet[] additionalDocs;
     private String[] keywords;
-    
+
     private ServiceReader serviceReader;
     private ServiceManager serviceManager;
 
@@ -1525,7 +1505,7 @@ public class TestSuite
     private static HashMap observedFiles;
 
     private final NotificationLogger notifLogger = new NotificationLogger(null);
-    
+
     public static final String TM_CONTEXT_NAME = "tmcontext";
-    
+
 }
