@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2001, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2001, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -63,17 +63,17 @@ public class WorkDirectory {
         Fault(I18NResourceBundle i18n, String s) {
             super(i18n.getString(s));
         }
-        
+
         Fault(I18NResourceBundle i18n, String s, Object o) {
             super(i18n.getString(s, o));
         }
-        
+
         Fault(I18NResourceBundle i18n, String s, Object[] o) {
             super(i18n.getString(s, o));
         }
     }
-    
-    
+
+
     /**
      * Signals that the template pointed to by that directory is missing.
      */
@@ -109,7 +109,7 @@ public class WorkDirectory {
             super(i18n, key, f.getPath());
         }
     }
-    
+
     /**
      * Signals that a work directory already exists when an attempt is made
      * to create one.
@@ -119,7 +119,7 @@ public class WorkDirectory {
             super(i18n, key, f.getPath());
         }
     }
-    
+
     /**
      * Signals that a work directory does not match the given test suite.
      */
@@ -128,7 +128,7 @@ public class WorkDirectory {
             super(i18n, key, f.getPath());
         }
     }
-    
+
     /**
      * Signals that there is a problem trying to determine the test suite
      * appropriate for the work directory.
@@ -138,7 +138,7 @@ public class WorkDirectory {
             super(i18n, key, new Object[] {f.getPath(), o});
         }
     }
-    
+
     /**
      * Signals that there is a problem trying to initialize from the data in
      * the work directory.
@@ -148,7 +148,7 @@ public class WorkDirectory {
             super(i18n, key, new Object[] {f.getPath(), o});
         }
     }
-    
+
     /**
      * Signals that a problem occurred while trying to purge files in work directory.
      */
@@ -157,7 +157,7 @@ public class WorkDirectory {
             super(i18n, key, new Object[] {f.getPath(), o});
         }
     }
-    
+
     /**
      * Check if a directory is a work directory. This is intended to be a quick
      * check, rather than exhaustive one; as such, it simply checks for the
@@ -169,14 +169,14 @@ public class WorkDirectory {
     public static boolean isWorkDirectory(File dir) {
         //System.err.println("WorkDirectory.isWorkDirectory: " + dir);
         File jtData = new File(dir, JTDATA);
-        
+
         if (jtData.exists() && jtData.isDirectory())
             // should consider checking for existence of test suite data
             return true;
         else
             return false;
     }
-    
+
     /**
      * Check if a directory is an empty directory.
      * @param dir the directory to be checked
@@ -189,7 +189,7 @@ public class WorkDirectory {
         } else
             return false;
     }
-    
+
     /**
      * Do sanity check of workdir.  All critical areas must be
      * read-write.
@@ -197,18 +197,18 @@ public class WorkDirectory {
     public static boolean isUsableWorkDirectory(File dir) {
         if (dir == null || !isUsable(dir))
             return false;
-        
+
         try {
             File canonDir = canonicalize(dir);
             File jtData = new File(canonDir, JTDATA);
-            
+
             // could call isWorkDirectory(File)
             if (!isUsable(jtData))
                 return false;
-            
+
             // all files in jtData must be read-write
             File[] content = jtData.listFiles();
-            
+
             // could even look for key files while doing this loop
             if (content != null && content.length > 0)
                 for (int i = 0; i < content.length; i++)
@@ -217,23 +217,23 @@ public class WorkDirectory {
         } catch (BadDirectoryFault f) {
             return false;
         }
-        
+
         return true;
     }
-    
+
     private static boolean isUsable(File f) {
         if (!f.exists())
             return false;
-        
+
         if (!f.canRead())
             return false;
-        
+
         if (!f.canWrite())
             return false;
-        
+
         return true;
     }
-    
+
     /**
      * Create a new work directory with a given name, and for a given test suite.
      * @param dir the directory to be created as a work directory.
@@ -256,7 +256,7 @@ public class WorkDirectory {
         //System.err.println("WD.create: " + dir);
         return createOrConvert(dir, ts, true);
     }
-    
+
     /**
      * Convert an existing directory into a work directory.
      * @param dir the directory to be converted to a work directory
@@ -282,34 +282,34 @@ public class WorkDirectory {
             throw new FileNotFoundException(dir.getPath());
         return createOrConvert(dir, ts, false);
     }
-    
+
     private static WorkDirectory createOrConvert(File dir, TestSuite ts, boolean checkEmpty)
     throws BadDirectoryFault, WorkDirectoryExistsFault, InitializationFault {
         File canonDir;
         File jtData;
         ArrayList undoList = new ArrayList();
-        
+
         try {
             if (dir.exists()) {
                 canonDir = canonicalize(dir);
                 jtData = new File(canonDir, JTDATA);
-                
-                
+
+
                 if (!canonDir.isDirectory())
                     throw new BadDirectoryFault(i18n, "wd.notDirectory", canonDir);
-                
+
                 if (!canonDir.canRead())
                     throw new BadDirectoryFault(i18n, "wd.notReadable", canonDir);
-                
+
                 if (jtData.exists() && jtData.isDirectory())
                     throw new WorkDirectoryExistsFault(i18n, "wd.alreadyExists", canonDir);
-                
+
                 if (checkEmpty) {
                     String[] list = canonDir.list();
                     if (list != null && list.length > 0)
                         throw new BadDirectoryFault(i18n, "wd.notEmpty", canonDir);
                 }
-                
+
                 // actively flush the dirMap for canonDir?
             } else {
                 if (!mkdirs(dir, undoList))
@@ -317,23 +317,23 @@ public class WorkDirectory {
                 canonDir = canonicalize(dir);
                 jtData = new File(canonDir, JTDATA);
             }
-            
+
             if (!mkdirs(jtData, undoList))
                 throw new BadDirectoryFault(i18n, "wd.cantCreate", canonDir);
-            
+
             try {
                 WorkDirectory wd;
-                
+
                 synchronized (dirMap) {
                     wd = new WorkDirectory(canonDir, ts, null);
                     // dirMap.put(canonDir, new WeakReference(wd));
                 }
-                
+
                 wd.saveTestSuiteInfo();
-                
+
                 // create successful -- so zap the undoList
                 undoList = null;
-                
+
                 return wd;
             } catch (IOException e) {
                 throw new BadDirectoryFault(i18n, "wd.cantWriteTestSuiteInfo", canonDir, e);
@@ -343,34 +343,34 @@ public class WorkDirectory {
                 undo(undoList);
         }
     }
-    
+
     public String getLogFileName() {
         return logFileName;
     }
-    
+
     private static boolean mkdirs(File dir, ArrayList undoList) {
         File parent = dir.getParentFile();
         if (parent != null && !parent.exists()) {
             if (!mkdirs(parent, undoList))
                 return false;
         }
-        
+
         if (dir.mkdir()) {
             //System.err.println("WD.mkdir " + dir);
             undoList.add(dir);
             return true;
         }
-        
+
         return false;
     }
-    
+
     private static void undo(ArrayList undoList) {
         for (int i = undoList.size() - 1; i >= 0; i--) {
             File f = (File) (undoList.get(i));
             delete(f);
         }
     }
-    
+
     private static void delete(File f) {
         //System.err.println("WD.delete " + f);
         if (f.isDirectory()) {
@@ -383,94 +383,108 @@ public class WorkDirectory {
         f.delete();
     }
 
-	public static void changeTemplate(File dir, File newTemplate) {
-		File templateData = new File(dir, JTDATA + File.separator + "template.data");
-		if (templateData.exists()) {
-			Properties p = new Properties();
-			final String absolutePath = templateData.getAbsolutePath();
-			try {
-				p.load(new FileInputStream(absolutePath));
-				p.setProperty("file", newTemplate.getCanonicalPath());
-				p.store(new FileOutputStream(absolutePath), "template information file - do not modify");
-			} catch (IOException e) {
-				e.printStackTrace();
-			}
-		}
-	}
+        public static void changeTemplate(File dir, File newTemplate) {
+            File templateData = new File(dir, JTDATA + File.separator + "template.data");
+            if (templateData.exists()) {
+                Properties p = new Properties();
+                final String absolutePath = templateData.getAbsolutePath();
+                FileInputStream fis = null;
+                FileOutputStream fos = null;
+                try {
+                    fis = new FileInputStream(absolutePath);
+                    p.load(fis);
+                    p.setProperty("file", newTemplate.getCanonicalPath());
+                    fos = new FileOutputStream(absolutePath);
+                    p.store(fos, "template information file - do not modify");
+                } catch (IOException e) {
+                        e.printStackTrace();
+                }
+                finally {
+                    try { if (fis != null) fis.close(); } catch (IOException e) {}
+                    try { if (fos != null) fos.close(); } catch (IOException e) {}
+                }
+            }
+        }
 
-	private static void validateWD(File dir)
-	throws FileNotFoundException, 
-		   BadDirectoryFault, 
-		   NotWorkDirectoryFault,
-		   TemplateMissingFault {
+    private static void validateWD(File dir)
+            throws FileNotFoundException,
+            BadDirectoryFault,
+            NotWorkDirectoryFault,
+            TemplateMissingFault {
 
-        if (!dir.exists())
+        if (!dir.exists()) {
             throw new FileNotFoundException(dir.getPath());
-        
+        }
+
         File canonDir = canonicalize(dir);
-        
-        if (!canonDir.isDirectory())
+
+        if (!canonDir.isDirectory()) {
             throw new BadDirectoryFault(i18n, "wd.notDirectory", canonDir);
-        
-        if (!canonDir.canRead())
+        }
+
+        if (!canonDir.canRead()) {
             throw new BadDirectoryFault(i18n, "wd.notReadable", canonDir);
-        
+        }
+
         File jtData = new File(canonDir, JTDATA);
-        if (!jtData.exists())
+        if (!jtData.exists()) {
             throw new NotWorkDirectoryFault(i18n, "wd.notWorkDir", canonDir);
+        }
 
-		File templateData = new File(canonDir, JTDATA + File.separator + "template.data");
-		if (templateData.exists()) {
-			Properties p = new Properties();
-			try {
-				p.load(new FileInputStream(templateData.getAbsolutePath()));
-			} catch (IOException e) {
-				e.printStackTrace();
-			}
-                        
-			String templateFile = p.getProperty("file");
-			if (!new File(templateFile).exists()) {
+        File templateData = new File(canonDir, JTDATA + File.separator + "template.data");
+        if (templateData.exists()) {
+            Properties p = new Properties();
+            FileInputStream fis = null;
+            try {
+                fis = new FileInputStream(templateData.getAbsolutePath());
+                p.load(fis);
+            } catch (IOException e) {
+                e.printStackTrace();
+            }
+            finally {
+                try { if (fis != null) fis.close(); } catch (IOException e) {}
+            }
 
-                            try {
-                                // try to calculate relocation
+            String templateFile = p.getProperty("file");
+            if (!new File(templateFile).exists()) {
 
-                                String oldWDpath = loadWdInfo(jtData).getProperty(PREV_WD_PATH);
-                                String[] begins = getDiffInPaths(dir.getPath(), oldWDpath);
-                                if (begins != null) {
-                                    if (templateFile.startsWith(begins[1])) {
-                                        String candidat = begins[0] + templateFile.substring(begins[1].length());
-                                        if (!new File(candidat).exists()) {
-                                            throw new TemplateMissingFault(i18n, "wd.templateMissing", canonDir, templateFile);
-                                        } else {
-                                            // update WD info
-                                            p.setProperty("file", candidat);
-                                            FileOutputStream out = null;
-                                            try {
-                                                out = new FileOutputStream(templateData);
-                                            }
-                                            catch (FileNotFoundException e) {
-                                                // should log the error
-                                                // e.printStackTrace()
-                                                return;
-                                            }
-
-                                            try {
-                                                p.save(out, "template information file - do not modify");
-                                            }
-                                            finally {
-                                                out.close();
-                                            }
-
-                                        }
-                                    }
-                                }
-                            } catch (IOException ex) {
+                try {
+                    // try to calculate relocation
+                    String oldWDpath = loadWdInfo(jtData).getProperty(PREV_WD_PATH);
+                    String[] begins = getDiffInPaths(dir.getPath(), oldWDpath);
+                    if (begins != null) {
+                        if (templateFile.startsWith(begins[1])) {
+                            String candidat = begins[0] + templateFile.substring(begins[1].length());
+                            if (!new File(candidat).exists()) {
                                 throw new TemplateMissingFault(i18n, "wd.templateMissing", canonDir, templateFile);
+                            } else {
+                                // update WD info
+                                p.setProperty("file", candidat);
+                                FileOutputStream out = null;
+                                try {
+                                    out = new FileOutputStream(templateData);
+                                } catch (FileNotFoundException e) {
+                                    // should log the error
+                                    // e.printStackTrace()
+                                    return;
+                                }
+
+                                try {
+                                    p.save(out, "template information file - do not modify");
+                                } finally {
+                                    try { if (out != null) out.close(); } catch (IOException e) {}
+                                }
+
                             }
-				
-			}  
-		}
-	}
+                        }
+                    }
+                } catch (IOException ex) {
+                    throw new TemplateMissingFault(i18n, "wd.templateMissing", canonDir, templateFile);
+                }
+
+            }
+        }
+    }
 
     /*
      * This method calculates common tail and returns
@@ -533,41 +547,41 @@ public class WorkDirectory {
             InitializationFault,
             TemplateMissingFault {
 
-	 validateWD(dir);
+         validateWD(dir);
 
      File canonDir = canonicalize(dir);
         File jtData = new File(canonDir, JTDATA);
-     
+
         WorkDirectory wd;
-        
+
         synchronized (dirMap) {
             // sync-ed to make dirMap data consistent
             WeakReference ref = (WeakReference)(dirMap.get(canonDir));
             wd = (ref == null ? null : (WorkDirectory) (ref.get()));
-            
+
             if (wd != null)
                 return wd;
-            
+
             Properties tsInfo;
             TestSuite ts;
-            
+
             try {
                 tsInfo = loadTestSuiteInfo(jtData);
                 String root = tsInfo.getProperty(TESTSUITE_ROOT);
                 if (root == null)
                     throw new BadDirectoryFault(i18n, "wd.noTestSuiteRoot", canonDir);
-                
+
                 File tsr = new File(root);
                 if (!tsr.exists())
                     throw new TestSuiteFault(i18n, "wd.cantFindTestSuite", canonDir, tsr.getPath());
-                
+
                 ts = TestSuite.open(tsr);
-                
+
                 String wdID = (tsInfo == null ? null : (String) (tsInfo.get(TESTSUITE_ID)));
                 String tsID = ts.getID();
                 if (!(wdID == null ? "" : wdID).equals(tsID == null ? "" : tsID))
                     throw new MismatchFault(i18n, "wd.mismatchID", canonDir);
-                
+
             }   // try
             catch (FileNotFoundException e) {
                 throw new BadDirectoryFault(i18n, "wd.noTestSuiteFile", canonDir);
@@ -576,15 +590,15 @@ public class WorkDirectory {
             } catch (TestSuite.Fault e) {
                 throw new TestSuiteFault(i18n, "wd.cantOpenTestSuite", canonDir, e.toString());
             }   // catch
-            
+
             wd = new WorkDirectory(canonDir, ts, tsInfo);
-            
+
             // dirMap.put(canonDir, new WeakReference(wd));
         }   // sync block
-        
+
         return wd;
     }
-    
+
     /**
      * Open an existing work directory, using an explicit test suite. Any information
      * about the test suite previously associated with this work directory is overwritten
@@ -616,18 +630,18 @@ public class WorkDirectory {
             MismatchFault,
             InitializationFault,
             TemplateMissingFault {
-	 
-	 validateWD(dir);
+
+         validateWD(dir);
 
         File canonDir = canonicalize(dir);
         File jtData = new File(canonDir, JTDATA);
-        
+
         WorkDirectory wd = null;
         synchronized (dirMap) {
             WeakReference ref = (WeakReference)(dirMap.get(canonDir));
             if (ref != null)
                 wd = (WorkDirectory)(ref.get());
-            
+
             if (wd == null) {
                 Properties tsInfo;
                 try {
@@ -635,12 +649,12 @@ public class WorkDirectory {
                 } catch (IOException e) {
                     tsInfo = null;
                 }
-                
+
                 String wdID = (tsInfo == null ? null : (String) (tsInfo.get(TESTSUITE_ID)));
                 String tsID = testSuite.getID();
                 if (!(wdID == null ? "" : wdID).equals(tsID == null ? "" : tsID))
                     throw new MismatchFault(i18n, "wd.mismatchID", canonDir);
-                
+
                 // no existing instance, create one
                 try {
                     wd = new WorkDirectory(canonDir, testSuite, tsInfo);
@@ -651,10 +665,10 @@ public class WorkDirectory {
                 }
             }   // if
         }   // sync
-        
+
         return wd;
     }
-    
+
     /**
      * Create a WorkDirectory object for a given directory and testsuite.
      * The directory is assumed to be valid (exists(), isDirectory(), canRead() etc)
@@ -665,7 +679,7 @@ public class WorkDirectory {
         this.root = root;
         this.testSuite = testSuite;
         jtData = new File(root, JTDATA);
-        
+
         if (jtData != null) {
             File loggerFile = getSystemFile(LoggerFactory.LOGFILE_NAME + "." + LoggerFactory.LOGFILE_EXTENSION);
             logFileName = loggerFile.getAbsolutePath();
@@ -675,12 +689,12 @@ public class WorkDirectory {
             } catch (IOException ioe) {
                 testSuite.getNotificationLog(this).throwing("WorkDirectory", "WorkDirectory(File,TestSuite,Map)", ioe);
             }
-            
+
         }
-        
+
         // should consider saving parameter interview here;
         // -- possibly conditionally (don't need to write it in case of normal open)
-        
+
         if (tsInfo != null) {
             String testC = (String) (tsInfo.get(TESTSUITE_TESTCOUNT));
             int tc;
@@ -696,13 +710,13 @@ public class WorkDirectory {
             testCount = tc;
         } else
             testCount = testSuite.getEstimatedTestCount();
-        
+
         testSuiteID = testSuite.getID();
         if (testSuiteID == null)
             testSuiteID = "";
 
         doWDinfo(jtData, testSuite);
-        
+
     }
 
 
@@ -732,7 +746,7 @@ public class WorkDirectory {
     public File getRoot() {
         return root;
     }
-    
+
     /**
      * Get the root directory for this work directory.
      * @return the path of the root directory for this work directory
@@ -740,7 +754,7 @@ public class WorkDirectory {
     public String getPath() {
         return root.getPath();
     }
-    
+
     /**
      * Get the data directory for this work directory.
      * @return the system (jtData) directory for this work directory
@@ -748,7 +762,7 @@ public class WorkDirectory {
     public File getJTData() {
         return jtData;
     }
-    
+
     /**
      * Get a file in this work directory.
      * @param name the name of a file within this work directory
@@ -757,7 +771,7 @@ public class WorkDirectory {
     public File getFile(String name) {
         return new File(root, name);
     }
-    
+
     /**
      * Get a file in the system directory for this work directory.
      * @param name the name of a file within the system (jtData) directory
@@ -766,7 +780,7 @@ public class WorkDirectory {
     public File getSystemFile(String name) {
         return new File(jtData, name);
     }
-    
+
     /**
      * Get the test suite for this work directory.
      * @return the test suite for which this is a work directory
@@ -774,7 +788,7 @@ public class WorkDirectory {
     public TestSuite getTestSuite() {
         return testSuite;
     }
-    
+
     /**
      * Find out the number of tests in the entire test suite.
      * This number is collected from either a previous iteration of the
@@ -786,7 +800,7 @@ public class WorkDirectory {
     public int getTestSuiteTestCount() {
         return testCount;
     }
-    
+
     /**
      * Specify the total number of tests found in this testsuite.
      * When available, this class prefers to use this number rather
@@ -798,7 +812,7 @@ public class WorkDirectory {
     public void setTestSuiteTestCount(int num) {
         if (num != testCount) {
             testCount = num;
-            
+
             try {
                 saveTestSuiteInfo();
             } catch (IOException e) {
@@ -806,8 +820,8 @@ public class WorkDirectory {
             }
         }
     }
-    
-    
+
+
     /**
      * Get a test result table containing the test results in this work directory.
      * @return a test result table containing the test results in this work directory
@@ -818,10 +832,10 @@ public class WorkDirectory {
         if (testResultTable == null ) {
             testResultTable = new TestResultTable(this);
         }
-        
+
         return testResultTable;
     }
-    
+
     /**
      * Set a test result table containing the test descriptions for the tests in this
      * test suite.
@@ -835,31 +849,31 @@ public class WorkDirectory {
     public void setTestResultTable(TestResultTable trt) {
         if (trt == null)
             throw new NullPointerException();
-        
+
         if (trt == testResultTable) {
             // already set to the correct value
             return;
         }
-        
+
         if (testResultTable != null && testResultTable != trt) {
             // already set to something else
             throw new IllegalStateException();
         }
-        
+
         WorkDirectory trt_wd = trt.getWorkDirectory();
         if (trt_wd != null && trt_wd != this)
             throw new IllegalArgumentException();
-        
+
         if (trt_wd == null)
             trt.setWorkDirectory(this);
-        
+
         testResultTable = trt;
     }
 
     public boolean isTRTSet() {
         return testResultTable != null;
     }
-    
+
     /**
      * Print a text message to the workdir logfile.
      * A single line of text which is as short as possible is highly
@@ -874,7 +888,7 @@ public class WorkDirectory {
         ensureLogFileInitialized();
         logFile.log(i18n, key);
     }
-    
+
     /**
      * Print a text message to the workdir logfile.
      * A single line of text which is as short as possible is highly
@@ -891,7 +905,7 @@ public class WorkDirectory {
         ensureLogFileInitialized();
         logFile.log(i18n, key, arg);
     }
-    
+
     /**
      * Print a text message to the workdir logfile.
      * A single line of text which is as short as possible is highly
@@ -908,12 +922,12 @@ public class WorkDirectory {
         ensureLogFileInitialized();
         logFile.log(i18n, key, args);
     }
-    
+
     private void ensureLogFileInitialized() {
         if (logFile == null)
             logFile = new LogFile(getSystemFile("log.txt"));
     }
-    
+
     /**
      * See <code>putTestAnnotation(String,String,String).
      *
@@ -922,7 +936,7 @@ public class WorkDirectory {
     public synchronized void putTestAnnotation(TestResult tr, String key, String value) {
         putTestAnnotation(tr.getTestName(), key, value);
     }
-    
+
     /**
      * Add an annotation for the given test.
      * @param testName Test for which the annotation should be added.  This is
@@ -934,13 +948,13 @@ public class WorkDirectory {
      */
     public synchronized void putTestAnnotation(String testName, String key, String value) {
         loadAnnotations();
-        
+
         HashMap<String,String> map = null;
         if (annotationMap == null)
             annotationMap = new TreeMap<String,HashMap<String,String>>();
         else
             map = annotationMap.get(testName);
-        
+
         if (map == null) {
             map = new HashMap<String,String>();
             annotationMap.put(testName, map);
@@ -950,10 +964,10 @@ public class WorkDirectory {
             map.put(key, value);
         else
             map.remove(key);
-        
+
         saveAnnotations();
     }
-    
+
     /**
      * Get any annotations for the given test.
      *
@@ -967,10 +981,10 @@ public class WorkDirectory {
         loadAnnotations();
         if (annotationMap == null)
             return null;
-        
+
         return annotationMap.get(testName);
     }
-    
+
     /**
      * Get any annotations for the given test in this work directory.
      * The annotations take the form of a map of strings for both the key and
@@ -982,10 +996,10 @@ public class WorkDirectory {
     public synchronized Map<String,String> getTestAnnotations(TestResult tr) {
         if (tr == null)
             throw new NullPointerException();
-        
+
         return getTestAnnotations(tr.getTestName());
     }
-    
+
     /**
      * Clean the contents of the given path.  If <tt>path</tt> is a
      * directory, it is recursively deleted.  If it is a file, that file
@@ -1005,14 +1019,14 @@ public class WorkDirectory {
     public boolean purge(String path) throws PurgeFault {
         if (path == null)
             return false;
-        
+
         boolean result = true;
-        
+
         File f = (path.length() == 0 ? root : getFile(path));
-        
+
         if (!f.exists())
             return false;
-        
+
         if (f.isDirectory())
             result = recursivePurge(f, path);
         else {
@@ -1020,19 +1034,19 @@ public class WorkDirectory {
             result = f.delete();
             testResultTable.resetTest(path);
         }
-        
+
         return result;
     }
-    
+
     synchronized void clearAnnotations(TestResult tr) {
         loadAnnotations();
         if (annotationMap != null)
             annotationMap.remove(tr.getTestName());
         saveAnnotations();
     }
-    
+
     // ------------ PRIVATE --------------
-    
+
     /**
      * Load or save the annotations to secondary storage (disk).
      * Methods should call this before attempting to access annotations, in
@@ -1043,11 +1057,11 @@ public class WorkDirectory {
         if (annotationMap  == null)
             loadAnnotationsFromDisk();
     }
-    
+
     private void loadAnnotationsFromDisk() {
         File aFile = getSystemFile(TEST_ANNOTATION_FILE);
         FileInputStream fis = null;
-        
+
         if (aFile.exists() && aFile.canRead()) {
             try {
                 fis = new FileInputStream(aFile);
@@ -1055,11 +1069,11 @@ public class WorkDirectory {
                 // should never happen
                 e.printStackTrace();
             }
-            
+
             DataInputStream reader = new DataInputStream(new BufferedInputStream(fis));
-            
+
             annotationMap = new TreeMap<String,HashMap<String,String>>();
-            
+
             try {
                 while(reader.available() > 0) {
                     try {
@@ -1078,16 +1092,17 @@ public class WorkDirectory {
                     }
                 }
                 reader.close();
-            } catch(IOException e) {
-                // exception from reader.available()
+            } catch(IOException ex) {
+                ex.printStackTrace();
+                try { if (reader != null) reader.close(); } catch (IOException e) {}
             }
-            
+
             if (annotationMap.size() == 0)
                 annotationMap = null;
 
         }
     }
-    
+
     private void saveAnnotations() {
         // must write even if the map is now empty
         // remove file if map empty
@@ -1102,21 +1117,21 @@ public class WorkDirectory {
             }
         } else {
             FileOutputStream fos = null;
-            
+
             try {
                 fos = new FileOutputStream(aFile);
             } catch (FileNotFoundException e) {
                 // should not happen
                 e.printStackTrace();
             }
-            
+
             DataOutputStream writer = new DataOutputStream(new BufferedOutputStream(fos));
             // writes a triplet
             for (String s: annotationMap.keySet()) {
                 HashMap<String,String> map = annotationMap.get(s);
                 try {
                     for (String key: map.keySet()) {
-		        writer.writeUTF(s);    // 1
+                        writer.writeUTF(s);    // 1
                         writer.writeUTF(key);      // 2
                         writer.writeUTF(map.get(key));  // 3
                     }
@@ -1124,7 +1139,7 @@ public class WorkDirectory {
                     e.printStackTrace();    // XXX
                 }
             }   // for
-            
+
             try {
                 writer.close();
             } catch(IOException e) {
@@ -1133,7 +1148,7 @@ public class WorkDirectory {
             }
         }
     }
-    
+
     /**
      * @return False if any part of the removal process failed to complete.
      * @throws PurgeFault If the file cannot be removed; the message field
@@ -1143,23 +1158,23 @@ public class WorkDirectory {
     private boolean recursivePurge(File dir, String pathFromRoot) throws PurgeFault {
         boolean result = true;
         File[] files = dir.listFiles();
-        
+
         if (files == null) {
             // make log entry
             // according to spec, this is not an empty directory, but a bad path
             // experienced with a symlink which went nowhere
             return false;
         }
-        
+
         for (int i = 0; i < files.length; i++) {
             File f = files[i];
-            
+
             String p; // root-relative path for f
             if (pathFromRoot.length() == 0)
                 p = f.getName();
             else
                 p = pathFromRoot + "/" + f.getName();
-            
+
             if (f.isFile()) {
                 result &= f.delete();
                 if (f.getName().endsWith(TestResult.EXTN))
@@ -1170,10 +1185,10 @@ public class WorkDirectory {
                 result &= f.delete();
             }
         }
-        
+
         return result;
     }
-    
+
     private static Properties loadTestSuiteInfo(File jtData) throws FileNotFoundException, IOException {
         return loadInfo(jtData, TESTSUITE);
     }
@@ -1213,10 +1228,10 @@ public class WorkDirectory {
     private synchronized void saveInfo(Properties p, String name, String descr) throws IOException {
         File f = File.createTempFile(name, ".new", jtData);
         OutputStream out = new BufferedOutputStream(new FileOutputStream(f));
-        
+
         p.store(out, descr);
         out.close();
-        
+
         // trying to get near-atomic updates to this file
         File to = new File(jtData, name);
         if (!f.renameTo(to)) {
@@ -1225,7 +1240,7 @@ public class WorkDirectory {
             f.renameTo(to);
         }
     }
-    
+
     private static File canonicalize(File dir) throws BadDirectoryFault {
         try {
             return dir.getCanonicalFile();
@@ -1233,7 +1248,7 @@ public class WorkDirectory {
             throw new BadDirectoryFault(i18n, "wd.cantCanonicalize", dir, e);
         }
     }
-    
+
     private File root;
     private TestSuite testSuite;
     private String testSuiteID;
@@ -1253,10 +1268,8 @@ public class WorkDirectory {
     private static final String TESTSUITE_NAME = "name";
     private static final String TESTSUITE_ROOT = "root";
     private static final String TESTSUITE_TESTCOUNT = "testCount";
-    
+
     private static I18NResourceBundle i18n = I18NResourceBundle.getBundleForClass(WorkDirectory.class);
-    
+
     private static final String TEST_ANNOTATION_FILE = "test_annotations.dat";
-    
-    
 }
