@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -48,6 +48,7 @@ import com.sun.javatest.tool.UIFactory;
 import com.sun.javatest.tool.WorkDirChooser;
 import com.sun.javatest.util.Debug;
 import com.sun.javatest.util.I18NResourceBundle;
+
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.GridBagConstraints;
@@ -93,7 +94,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         RunTestsHandler.Observer, ET_SessionControl, Session.Observer {
 
 
-    protected final BasicSession session;
+    protected final SessionExt session;
     protected final TestSuite testSuite;
     protected UIFactory uif;
     protected JComponent parent;
@@ -133,7 +134,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         this.cm = cm;
         this.uif = uif;
         this.parent = parent;
-        session = (BasicSession)createEmptySession();
+        session = createEmptySession();
         initActions();
         initHistoryListeners();
     }
@@ -176,7 +177,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         // save work dir and ip
         session.save(m);
     }
-    
+
     public void restore(Map m) {
         try {
             session.restore(m);
@@ -202,7 +203,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
      * @return created session.
      * @throws com.sun.javatest.exec.Session.Fault
      */
-    protected Session createEmptySession() throws Fault {
+    protected SessionExt createEmptySession() throws Fault {
         return new BasicSession(testSuite);
     }
 
@@ -235,17 +236,13 @@ public class BasicSessionControl implements InterviewEditor.Observer,
     }
 
     public void ensureInterviewUpToDate() {
-        if (session instanceof BasicSession) {
-            try {
-                ((BasicSession)session).ensureInterviewUpToDate();
-            } catch (Exception ex) {
-                if (debug > 0) {
-                    ex.printStackTrace(Debug.getWriter());
-                }
-                uif.showError("exec.loadInterview", ex.toString());
+        try {
+            session.reloadInterview();
+        } catch (Exception ex) {
+            if (debug > 0) {
+                ex.printStackTrace(Debug.getWriter());
             }
-        } else {
-            throw new IllegalStateException(i18n.getString("bcc.notBasicConfigInstance.err", session.getClass()));
+            uif.showError("exec.loadInterview", ex.toString());
         }
     }
 
@@ -266,10 +263,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
 
     public void whatToDoWhenConfigNotReadyButUserPressedStartButton(
             final Action startAction) {
-        if (!(session instanceof BasicSession)) {
-            return;
-        }
-        final InterviewParameters ip = ((BasicSession)session).config;
+        final InterviewParameters ip = session.getInterviewParameters();
 
 
         // configuration is incomplete, possibly not even started:
@@ -314,10 +308,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
     }
 
     void editConfigWithErrorMessage() {
-        if (!(session instanceof BasicSession)) {
-            return;
-        }
-        final InterviewParameters ip = ((BasicSession)session).config;
+        final InterviewParameters ip = session.getInterviewParameters();
         String errorMessage = ip.getErrorMessage();
         int option = (errorMessage == null) ?
             uif.showOKCancelDialog("rh.mustConfigure") :
@@ -341,7 +332,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
 
         }
     }
-    
+
     static void checkExcludeListUpdate(JComponent parent, boolean quietIfNoUpdate,
             Parameters interviewParams, TestSuite testSuite,
             WorkDirectory workDir, UIFactory uif) {
@@ -432,34 +423,34 @@ public class BasicSessionControl implements InterviewEditor.Observer,
     // arguably, this ought to be in InterviewParameters/BasicParameters
     protected boolean getNeedToAutoCheckExcludeList(Parameters params) {
         WorkDirectory workDir = params.getWorkDirectory();
-	InterviewParameters.ExcludeListParameters elp = session.getParameters().getExcludeListParameters();
-	if ( !(elp instanceof InterviewParameters.MutableExcludeListParameters))
-	    return false;
+        InterviewParameters.ExcludeListParameters elp = session.getParameters().getExcludeListParameters();
+        if ( !(elp instanceof InterviewParameters.MutableExcludeListParameters))
+            return false;
 
-	InterviewParameters.MutableExcludeListParameters melp = (InterviewParameters.MutableExcludeListParameters) elp;
-	if (melp.getExcludeMode() != InterviewParameters.MutableExcludeListParameters.LATEST_EXCLUDE_LIST)
-	    return false;
+        InterviewParameters.MutableExcludeListParameters melp = (InterviewParameters.MutableExcludeListParameters) elp;
+        if (melp.getExcludeMode() != InterviewParameters.MutableExcludeListParameters.LATEST_EXCLUDE_LIST)
+            return false;
 
-	// double check there is a URL to download from
-	if (params.getTestSuite().getLatestExcludeList() == null)
-	    return false;
+        // double check there is a URL to download from
+        if (params.getTestSuite().getLatestExcludeList() == null)
+            return false;
 
-	if (!melp.isLatestExcludeAutoCheckEnabled())
-	    return false;
+        if (!melp.isLatestExcludeAutoCheckEnabled())
+            return false;
 
-	if (melp.getLatestExcludeAutoCheckMode() == InterviewParameters.MutableExcludeListParameters.CHECK_EVERY_RUN)
-	    return true;
+        if (melp.getLatestExcludeAutoCheckMode() == InterviewParameters.MutableExcludeListParameters.CHECK_EVERY_RUN)
+            return true;
 
-	File local = workDir.getSystemFile("latest.jtx");
-	if (!local.exists())
-	    return true;
+        File local = workDir.getSystemFile("latest.jtx");
+        if (!local.exists())
+            return true;
 
-	long localLastModified = local.lastModified();
-	long now = System.currentTimeMillis();
-	int ageInDays = melp.getLatestExcludeAutoCheckInterval();
-	long ageInMillis = 24L * 60 * 60 * 1000 * ageInDays;
+        long localLastModified = local.lastModified();
+        long now = System.currentTimeMillis();
+        int ageInDays = melp.getLatestExcludeAutoCheckInterval();
+        long ageInMillis = 24L * 60 * 60 * 1000 * ageInDays;
 
-	return (ageInDays > 0) && (now > (localLastModified + ageInMillis));
+        return (ageInDays > 0) && (now > (localLastModified + ageInMillis));
     }
 
 
@@ -523,7 +514,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
     }
 
     /**
-     * Initializes interviewEditor. 
+     * Initializes interviewEditor.
      * @return true if initialized successfully, false if failed.
      */
     protected boolean initEditor() {
@@ -532,11 +523,11 @@ public class BasicSessionControl implements InterviewEditor.Observer,
             return true;
         }
 
-        InterviewParameters ip = (InterviewParameters)session.getParameters();
+        InterviewParameters ip = session.getInterviewParameters();
         if (ip == null || ip.getWorkDirectory() == null) {
             return false;
         }
-        interviewEditor = new InterviewEditor(parent, getUIFactory(), ip);
+        interviewEditor = createInterviewEditor(ip);
         if (cm != null) {
             interviewEditor.setCustomRenderers(cm.getCustomRenderersMap());
             interviewEditor.setContextManager(cm);
@@ -554,6 +545,16 @@ public class BasicSessionControl implements InterviewEditor.Observer,
 
     }
 
+    /**
+     * Creates an InterviewEditor instance. Subclasses might override this
+     * method to create an alternative editor.
+     *
+     * @param ip parameters to be edited
+     */
+    protected InterviewEditor createInterviewEditor(InterviewParameters ip) {
+        return new InterviewEditor(parent, getUIFactory(), ip);
+    }
+
     /**
      * Method returning UIFactory to be used to create InterviewEditor instance.
      */
@@ -581,15 +582,15 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         }
         interviewEditor.loadConfig();
     }
-    
+
     /**
      * Causes configuration editor to appear. If workdir is not set,
      * suggests to create one first.
      */
     public void edit() {
-        if (session.wd == null) {
+        if (session.getWorkDirectory() == null) {
             createWD();
-            if (session.wd == null) {
+            if (session.getWorkDirectory() == null) {
                 return;
             }
         }
@@ -608,11 +609,11 @@ public class BasicSessionControl implements InterviewEditor.Observer,
             if (session.isReady()) {
                 return;
             }
-            if (session.wd == null) {
+            if (session.getWorkDirectory() == null) {
                 showWorkDirDialog();
             }
 
-            if (session.wd == null) {
+            if (session.getWorkDirectory() == null) {
                 return;
             }
             if (!session.isReady()) {
@@ -670,8 +671,8 @@ public class BasicSessionControl implements InterviewEditor.Observer,
 
     protected void showConfigureDialog() {
         int option;
-        if (session.config.isStarted()) {
-            String errorMessage = session.config.getErrorMessage();
+        if (session.getInterviewParameters().isStarted()) {
+            String errorMessage = session.getInterviewParameters().getErrorMessage();
             if (errorMessage != null) {
                 option = uif.showOKCancelDialog("rh.configError", errorMessage);
             } else {
@@ -692,7 +693,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
      * Method to be invoked right after WD has been created/opened.
      */
     private void showConfig() {
-        if (session.config.getFile() == null) {
+        if (session.getInterviewParameters().getFile() == null) {
             newConfig();
         } else {
             showConfig(InterviewEditor.FULL_MODE);
@@ -749,11 +750,11 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         }
          */
     }
-    
+
     protected void initActions() {
         loadConfigAction = new ToolAction(uif, "ch.load") {
             public void actionPerformed(ActionEvent e) {
-                if (session.wd == null) {
+                if (session.getWorkDirectory() == null) {
                     showWorkDirDialog();
                 }
                 loadConfig();
@@ -762,11 +763,12 @@ public class BasicSessionControl implements InterviewEditor.Observer,
 
         newConfigAction = new ToolAction(uif, "ch.new") {
             public void actionPerformed(ActionEvent e) {
-                if (session.wd == null) {
+                if (session.getWorkDirectory() == null) {
                     showWorkDirDialog();
                 }
                 newConfig();
             }
+            @Override
             public Object getValue(String key) {
                 if (SessionView.ACTION_NAME.equals(key)){
                     return uif.getI18NString("ch.new2.act");
@@ -779,7 +781,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
                InterviewEditor.FULL_MODE, true) {
             @Override
             public void actionPerformed(ActionEvent e) {
-                if (session.wd == null) {
+                if (session.getWorkDirectory() == null) {
                     showWorkDirDialog();
                 }
                 showConfig(InterviewEditor.FULL_MODE);
@@ -854,6 +856,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
                     showConfig(InterviewEditor.FULL_MODE);
                 }
             }
+            @Override
             public Object getValue(String key) {
                 if (SessionView.ACTION_NAME.equals(key)){
                     return uif.getI18NString("ch.setWorkDir.act");
@@ -892,7 +895,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         if (params != null)
             ensureInterviewUpToDate();
 
-        boolean isWorkDirSet = ((BasicSession)session).wd != null;
+        boolean isWorkDirSet = session.getWorkDirectory() != null;
         boolean configCreated = session.getValue(BasicSession.CONFIG_NAME_PROP) != null;
         boolean editorNotVisible = !isEditorVisible();
         showFullConfigAction.setEnabled(params != null && configCreated && editorNotVisible);
@@ -909,7 +912,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         if (isWorkDirSet) {
             FileHistory h;
             if (configHistoryListener.getFileHistory() == null) {
-                h = FileHistory.getFileHistory(((BasicSession)session).wd, InterviewEditor.CONFIG_HISTORY);
+                h = FileHistory.getFileHistory(session.getWorkDirectory(), InterviewEditor.CONFIG_HISTORY);
                 configHistoryListener.setFileHistory(h);
             } else {
                 h = configHistoryListener.getFileHistory();
@@ -1066,8 +1069,8 @@ public class BasicSessionControl implements InterviewEditor.Observer,
                     // resetWorkDirectory();
                     uif.showError("ce.load.notAllowedDir", defaultConfigLoadPath);
                     return;
-                } 
-            } 
+                }
+            }
             loadInterviewFromFile(wd, latestConfigFile);
             h.add(latestConfigFile);
 
@@ -1075,7 +1078,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
             // interviewParams.load(latestConfigFile);
             //logLoadTime("exec.log.iload",System.currentTimeMillis()-time,
             //        workDir, latestConfigFile.getAbsolutePath());
-            
+
         }
     }
 
@@ -1233,13 +1236,6 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         }
     }
 
-    /*
-    protected static final Font BOLD_FONT = new Font("Ariel", Font.BOLD,
-            MetalLookAndFeel.getSystemTextFont().getSize());
-    protected static final Font ITALIC_FONT = new Font("Arial", Font.ITALIC, 
-            BOLD_FONT.getSize());
-    */
-
     private class ChangeConfigMenu extends JMenu implements MenuListener {
 
         ChangeConfigMenu() {
@@ -1247,6 +1243,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
             tests       = addMenuItem(CHANGE_TESTS,             InterviewEditor.STD_TESTS_MODE);
             excludeList = addMenuItem(CHANGE_EXCLUDE_LIST,      InterviewEditor.STD_EXCLUDE_LIST_MODE);
             keywords    = addMenuItem(CHANGE_KEYWORDS,          InterviewEditor.STD_KEYWORDS_MODE);
+            kfl         = addMenuItem(CHANGE_KFL,               InterviewEditor.STD_KFL_MODE);
             priorStatus = addMenuItem(CHANGE_PRIOR_STATUS,      InterviewEditor.STD_PRIOR_STATUS_MODE);
             environment = addMenuItem(CHANGE_ENVIRONMENT,       InterviewEditor.STD_ENVIRONMENT_MODE);
             concurrency = addMenuItem(CHANGE_CONCURRENCY,       InterviewEditor.STD_CONCURRENCY_MODE);
@@ -1258,7 +1255,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
             if (!(tests.isEnabled() || excludeList.isEnabled() ||
                     keywords.isEnabled() || priorStatus.isEnabled() ||
                     environment.isEnabled() || concurrency.isEnabled() ||
-                    timeoutFactor.isEnabled())) {
+                    timeoutFactor.isEnabled() || kfl.isEnabled())) {
                 setEnabled(false);
             }
             else {
@@ -1320,6 +1317,7 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         private JMenuItem tests;
         private JMenuItem excludeList;
         private JMenuItem keywords;
+        private JMenuItem kfl;
         private JMenuItem priorStatus;
         private JMenuItem environment;
         private JMenuItem concurrency;
@@ -1328,12 +1326,11 @@ public class BasicSessionControl implements InterviewEditor.Observer,
         private static final String CHANGE_TESTS = "test";
         private static final String CHANGE_EXCLUDE_LIST = "excl";
         private static final String CHANGE_KEYWORDS = "keyw";
+        private static final String CHANGE_KFL = "kfl";
         private static final String CHANGE_PRIOR_STATUS = "stat";
         private static final String CHANGE_ENVIRONMENT = "envt";
         private static final String CHANGE_CONCURRENCY = "conc";
         private static final String CHANGE_TIMEOUT_FACTOR = "time";
-        //private static final String CHANGE_OTHER = "other";
-
     };
 
 
