@@ -57,10 +57,10 @@ import javax.swing.JPanel;
 import javax.swing.JToolBar;
 
 
-public class ExecTool extends Tool implements ExecModel, 
+public class ExecTool extends Tool implements ExecModel,
         BasicSession.OrderedObserver {
 
-    Session session;
+    SessionExt session;
     ContextManager context;
     final ExecToolManager etm;
     final TestSuite testSuite;
@@ -89,7 +89,12 @@ public class ExecTool extends Tool implements ExecModel,
 
 
         sessionControl = controlFactory.createSessionControl();
-        session = sessionControl.getSession();
+        Session s = sessionControl.getSession();
+        if (s instanceof SessionExt) {
+            session = (SessionExt)s;
+        } else {
+            throw new Error(uif.getI18NString("bcc.notSessionExtInstance.err", s.getClass()));
+        }
         context.setCurrentConfig(session);
         controls.add(sessionControl);
 
@@ -146,7 +151,7 @@ public class ExecTool extends Tool implements ExecModel,
 
 //        initGUI();
     }
-    
+
     ContextManager createContextManager() {
         try {
            ContextManager cm = createContextManager(testSuite);
@@ -287,7 +292,7 @@ public class ExecTool extends Tool implements ExecModel,
         //asavdd(sessionControl.getStateViewPanel(), BorderLayout.SOUTH);
         //filterHandler.updateParameters();
         updateGUI();
-        
+
     }
 
     @Override
@@ -301,14 +306,14 @@ public class ExecTool extends Tool implements ExecModel,
     protected void restore(Map m) {
         for (ET_Control c:controls) {
             c.restore(m);
-        }        
+        }
     }
 
     @Override
     public void dispose() {
         // standard cleanup (remove refs to child components)
         super.dispose();
-	if (context != null)
+        if (context != null)
             context.dispose();
 
         for (ET_Control c:controls) {
@@ -335,19 +340,11 @@ public class ExecTool extends Tool implements ExecModel,
     }
 
     public WorkDirectory getWorkDirectory() {
-        Session cfg = sessionControl.getSession();
-        if (cfg != null && cfg instanceof BasicSession) {
-            return ((BasicSession)cfg).wd;
-        }
-        throw new IllegalStateException();
+        return session.getWorkDirectory();
     }
 
     public InterviewParameters getInterviewParameters() {
-        Session cfg = sessionControl.getSession();
-        if (cfg != null && cfg instanceof BasicSession) {
-            return (InterviewParameters)((BasicSession)cfg).getParameters();
-        }
-        throw new IllegalStateException();
+        return session.getInterviewParameters();
     }
 
     public FilterConfig getFilterConfig() {
@@ -382,9 +379,9 @@ public class ExecTool extends Tool implements ExecModel,
 
     /**
      * Returns action creating work directory.
-     * This ugly method violating the beautiful picture present here to
+     * This ugly method violates the beautiful picture, but present here to
      * preserve functionality of creating the WD from the File menu.
-     * Hopefully some day it will be illuminated.
+     * Hopefully some day it will be eliminated.
      *
      * @return real action or null
      */
@@ -397,9 +394,9 @@ public class ExecTool extends Tool implements ExecModel,
 
     /**
      * Returns action opening work directory for the TestSuite.
-     * This ugly method violating the beautiful picture present here to
+     * This ugly method violates the beautiful picture, but present here to
      * preserve functionality of creating the WD from the File menu.
-     * Hopefully some day it will be illuminated.
+     * Hopefully some day it will be eliminated.
      *
      * @return real action or null
      */
@@ -447,11 +444,9 @@ public class ExecTool extends Tool implements ExecModel,
      * @throws com.sun.javatest.exec.Session.Fault
      */
     public void update(InterviewParameters ip) throws Session.Fault {
-        if (session instanceof BasicSession) {
-            if (((BasicSession)session).config.getFile() != null) {
-                // someone already initialized IP
-                return;
-            }
+        if (session.getInterviewParameters().getFile() != null) {
+            // someone already initialized IP
+            return;
         }
         session.update(new BasicSession.U_NewConfig(ip));
     }
@@ -488,7 +483,7 @@ public class ExecTool extends Tool implements ExecModel,
     public void showConfigEditor() {
         sessionControl.edit();
     }
-    
+
     /**
      * Invoked after QSW
      */
@@ -595,7 +590,7 @@ public class ExecTool extends Tool implements ExecModel,
                 setI18NTitle("exec.title.tsName_wd.txt", new Object[]{testSuiteName, workDirPath});
             }
         }
- 
+
     }
 
     void pauseTreeCacheWork() {
@@ -627,21 +622,21 @@ public class ExecTool extends Tool implements ExecModel,
     void loadInterview(File file) {
         if (sessionControl instanceof BasicSessionControl) {
             BasicSessionControl bcc = (BasicSessionControl)sessionControl;
-            if (bcc.session.wd == null) {
+            if (bcc.session.getWorkDirectory() == null) {
                 throw new IllegalStateException();
             }
-            bcc.loadInterviewFromFile(bcc.session.wd, file);
+            bcc.loadInterviewFromFile(bcc.session.getWorkDirectory(), file);
         }
     }
 
     void saveTreeState(Map m) {
         testTreePanel.saveTreeState(m);
     }
-    
+
     void restoreTreeState(Map m) {
         testTreePanel.restoreTreeState(m);
     }
-    
+
     static final String TOOLBAR_PREF = "exec.toolbar";
     static final String FILTER_WARN_PREF = "exec.filterWarn";
     static final String TESTS2RUN_PREF = "exec.tests2runPop";
