@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2004, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2004, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -46,6 +46,7 @@ import com.sun.javatest.WorkDirectory;
 import com.sun.javatest.tool.Desktop;
 import com.sun.javatest.tool.FileOpener;
 import com.sun.javatest.tool.Preferences;
+import com.sun.javatest.tool.PreferencesPane;
 import com.sun.javatest.tool.UIFactory;
 import com.sun.javatest.tool.TestSuiteChooser;
 import com.sun.javatest.tool.Tool;
@@ -276,7 +277,7 @@ public class ExecToolManager extends ToolManager implements QSW_Listener
         }
     }
     @Override
-    public Preferences.Pane getPrefsPane() {
+    public PreferencesPane getPrefsPane() {
         if (prefsPane == null)
             prefsPane = new PrefsPane(getDesktop().getHelpBroker());
         return prefsPane;
@@ -550,7 +551,7 @@ public class ExecToolManager extends ToolManager implements QSW_Listener
     }
 
     protected ExecTool addNewExecTool(TestSuite ts, WorkDirectory wd,
-            InterviewParameters ip, String errorKey) { 
+            InterviewParameters ip, String errorKey) {
         Desktop d = getDesktop();
         ExecTool et;
         try {
@@ -651,7 +652,7 @@ public class ExecToolManager extends ToolManager implements QSW_Listener
             }
             addNewExecTool(wd.getTestSuite(), wd, null, "tmgr.errorOpenWorkDir");
         }
-    };    
+    };
     private Action createWorkDirAction = new ToolAction(i18n, "mgr.createWorkDir") {
         public void actionPerformed(ActionEvent e) {
 
