@@ -87,7 +87,7 @@ import com.sun.javatest.util.DynamicArray;
 import com.sun.javatest.util.I18NResourceBundle;
 import com.sun.javatest.util.StringArray;
 
-/** 
+/**
  * This panel is a split panel which has the testsuite tree on the left and a context
  * sensitive panel on the right.
  */
@@ -204,7 +204,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             }
             newConfigAlreadyApplied = true;
         }
-        
+
         String[] paths = null;
         String[] selectedPaths = null;
 
@@ -220,12 +220,12 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             if (tree != null && !(treeModel instanceof EmptyTestTreeModel)) {
                 TreePath[] ps = tree.snapshotOpenPaths();
                 paths = treeModel.pathsToStrings(ps);
-                
+
                 ps = tree.snapshotSelectedPaths();
                 selectedPaths = treeModel.pathsToStrings(ps);
             }
         }
-        
+
         this.params = newParams;
 
         if (treeModel instanceof EmptyTestTreeModel) {
@@ -279,11 +279,11 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         if (tree != null ) {
             tree.restoreSelection(selectedPaths);
         }
-        
+
         if (tree != null) {
             ensureTreeSelection();
         }
-        
+
     }
 
     private TreePath[] getTreePaths(String[] paths) {
@@ -299,7 +299,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                 if (tp != null) {
                     translatedPaths.add(tp);
                 }
-            }	// for (i)
+            }   // for (i)
 
             TreePath[] result = new TreePath[translatedPaths.size()];
             translatedPaths.toArray(result);
@@ -325,7 +325,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             }
         }
     }
-    
+
     @Override
     public void save(Map m) {
         // save the open paths
@@ -360,7 +360,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                     // get url
                     url = ((TT_TestNode) last).getTestResult().getTestName();
                 }
-                else if (last instanceof TT_BasicNode ) {	// tree node
+                else if (last instanceof TT_BasicNode ) {       // tree node
                     // get url
                     url = ((TT_BasicNode) last).getLongPath();
                 }
@@ -384,12 +384,12 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
     private TreePath nodeToPath(Object node, TestResultTable trt) {
     if (node instanceof TestResult) {
     TestResult tr = (TestResult)node;
-    
+
     }
-    else {	// tree node
+    else {      // tree node
     // trans url to path
     Object[] ttp = TestResultTable.getObjectPath((TreeNode)node);
-    
+
     if (ttp != null && ttp.length > 0)
     return new TreePath(ttp);
     else
@@ -554,9 +554,9 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                             } catch (java.lang.reflect.InvocationTargetException e) {
                             }
                         }   // outer try
-                    }	// for
+                    }   // for
                 }   // run()
-            };	// thread
+            };  // thread
 
             ActionListener al = new ActionListener() {
 
@@ -671,7 +671,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             public void run() {
                 //targetTree.restorePaths(paths);
             }
-        };	// Runnable
+        };      // Runnable
 
         EventQueue.invokeLater(restorer);
     }
@@ -694,7 +694,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
 
         if (what.length > 1) {
             //int confirm = uif.showYesNoDialog("treep.refreshNodeSure",
-            //		createNodeListString(createNodeList(what)));
+            //          createNodeListString(createNodeList(what)));
 
             String[] paths = createNodeList(what);
             DefaultListModel model = new DefaultListModel();
@@ -774,8 +774,8 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             TreePath[] tp = tree.snapshotOpenPaths();
             final String[] openUrls = treeModel.pathsToStrings(tp);
             final String[] selectedUrls = treeModel.pathsToStrings(tree.snapshotSelectedPaths());
-            
-            
+
+
             // disable all menu items
             setPopupItemsEnabled(false);
             final Thread t = new Thread() {
@@ -813,7 +813,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                                                     f.getMessage()
                                                 });
                                     }
-                                }	// catch
+                                }       // catch
                             }   // for
                         else {
                             for (int i = 0; i < finalNodes.length; i++) {
@@ -837,7 +837,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                                                     f.getMessage()
                                                 });
                                     }
-                                }	// catch
+                                }       // catch
                                 }   // for
                         }
                     } finally {
@@ -862,9 +862,9 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                         } catch (InterruptedException e) {
                         } catch (java.lang.reflect.InvocationTargetException e) {
                         }   // catch
-                    }	// finally
+                    }   // finally
                 }   // run()
-            };	// thread
+            };  // thread
 
             ActionListener al = new ActionListener() {
 
@@ -943,9 +943,9 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             }
         } else {
         }
-        tree.updateGUI();   
-        brPanel.updateGUI(); 
-        startTreeUpdate(); 
+        tree.updateGUI();
+        brPanel.updateGUI();
+        startTreeUpdate();
     }
 
     private synchronized void startTreeUpdate() {
@@ -985,11 +985,11 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                                     if (tree != null) {
                                         TreePath[] p = tree.snapshotOpenPaths();
                                         openPaths = treeModel.pathsToStrings(p);
-                                        
+
                                         selectedPaths = treeModel.pathsToStrings(tree.snapshotSelectedPaths());
-                                        
+
                                     }
-                                    
+
                                     if (pm != null) {
                                         pm.refreshTree();
                                     }
@@ -999,9 +999,9 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
 
                                         if (openPaths != null && openPaths.length > 0)
                                             tree.restorePaths(openPaths, true);
-                                        
+
                                         tree.restoreSelection(selectedPaths);
-                                        
+
                                     }
                                 } catch (TestResultTable.Fault f) {
                                 } finally {
@@ -1102,7 +1102,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         deck.setVisible(true);
         deckPanel.setVisible(true);
         splitPane.setDividerLocation(0.3);
-        splitPane.setResizeWeight(0.3);	    // 30% to left tree pane
+        splitPane.setResizeWeight(0.3);     // 30% to left tree pane
 
         ensureTreeSelection();
 
@@ -1160,32 +1160,32 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         purgeMI.setEnabled(false);
 
         // setup top toolbar
-	/*
+        /*
         JPanel topPanel = uif.createPanel("treeTb", new GridBagLayout(), false);
         // NOTE intentional space added below to defeat
         //  i18n check in build while this is commented out
         JLabel lab = uif.createLabel ("treep.filter", true);
-        
+
         JComponent selector = filterHandler.getFilterSelector();
         lab.setLabelFor(selector);
-        
+
         GridBagConstraints gbc = new GridBagConstraints();
         gbc.gridy = 0;
-        gbc.ipadx = 12;		    // JL&F
+        gbc.ipadx = 12;             // JL&F
         gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.anchor = GridBagConstraints.CENTER;
         gbc.gridwidth = GridBagConstraints.REMAINDER;
-        
+
         gbc.gridy = 1;
         gbc.gridwidth = 1;
         gbc.fill = GridBagConstraints.NONE;
         gbc.anchor = GridBagConstraints.WEST;
-        
+
         topPanel.add(lab, gbc);
         topPanel.add(selector, gbc);
-        
+
         topPanel.add(uif.createHorizontalStrut(15), gbc);
-        
+
         gbc.anchor = GridBagConstraints.EAST;
         gbc.fill = GridBagConstraints.BOTH;
         gbc.weightx = 3;
@@ -1232,7 +1232,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         if (paths == null || paths.length == 0) {
             return;
         }
-        
+
         if (paths.length == 1) {
             Object item = paths[0];
 
@@ -1291,7 +1291,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                         ((JavaTestContextMenu) (folderMenus.get(i))).updateState(url);
                     }   // for
                 }
-            } else {	// should not happen!
+            } else {    // should not happen!
                 if (testMenus != null) {
                     for (int i = 0; i < testMenus.size(); i++) {
                         ((JavaTestContextMenu) (testMenus.get(i))).getMenu().setEnabled(false);
@@ -1312,7 +1312,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                         ((JavaTestContextMenu) (folderMenus.get(i))).getMenu().setEnabled(false);
                     }   // for
                 }
-                
+
                 if (!(tree.getModel() instanceof EmptyTestTreeModel))
                     throw new JavaTestError("Unknown node type from JTree!");
             }
@@ -1349,7 +1349,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                 // currently enable/disabled state is only determined by the menu's
                 // ability to deal with multi selection
             }
-            
+
             if (testMenus != null) {
                 for (int i = 0; i < testMenus.size(); i++) {
                     JavaTestContextMenu m = (JavaTestContextMenu) (testMenus.get(i));
@@ -1407,7 +1407,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
 
         brPanel.setVisible(false);
         deck.show(testPanel);
-        
+
         // translate into path for display
         // could reoptimize to use path param
         // otherwise path param is mostly deprecated
@@ -1421,7 +1421,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         if (!tree.isVisible(jtPath)) {
             tree.scrollPathToVisible(jtPath);        // setup the test panel
         }
-        
+
         if (tr != testPanel.getTest()) {
             // select new node
             activeTest = tr.getTestName();
@@ -1494,14 +1494,14 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         if (tn != brPanel.getNode()) {
             // select new node
             brPanel.setNode(tn);
-            treeModel.setActiveNode(tn);	// hint to cache
+            treeModel.setActiveNode(tn);        // hint to cache
 
         } else {
             // should we ask for a refresh if == ?
         }
 
         // configure the right side title
-        if (tn.isRoot()) {		// root node, has no name
+        if (tn.isRoot()) {              // root node, has no name
             TestSuite ts = params.getTestSuite();
             String tsn = ts.getName();
             if (tsn != null) // use descriptive name of TestSuite
@@ -1579,7 +1579,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
         return uif.showCustomYesNoDialog(prefix, p);
     }
 
-    /** 
+    /**
      * Does this panel currently have data to work from.
      */
     private boolean isPopulated() {
@@ -1594,8 +1594,8 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
     private FilterSelectionHandler filterHandler;
     private ExecModel execModel;
     private JComponent parent;
-    private Thread bgThread;	    // in case disposal is required
-    private Map stateMap;		    // startup state, read-only
+    private Thread bgThread;        // in case disposal is required
+    private Map stateMap;                   // startup state, read-only
     private volatile boolean disposed;
     private PanelModel pm;
     private TestTree tree;
@@ -1615,12 +1615,12 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
     private JPanel deckPanel;
     private JTextField titleField;
     private Listener listener;
-    private TestSuite lastTs;	    // last recorded testsuite
+    private TestSuite lastTs;       // last recorded testsuite
     private Parameters params;
     private Parameters newParams;
     private boolean newConfigAlreadyApplied = false;
     private boolean initialized = false;
-    private static final int WAIT_DIALOG_DELAY = 3000;	    // 3 second delay
+    private static final int WAIT_DIALOG_DELAY = 3000;      // 3 second delay
     private static final String OPEN_PATHS_PREF = "openpaths";
     static protected boolean debug = Boolean.getBoolean("debug." + TestTreePanel.class.getName());
 
@@ -1709,12 +1709,12 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             TreePath tp = event.getPath();
             //Debug.println("collapsed " + ((TreeNode)(tp.getLastPathComponent())).getName());
             TreeNode tn = (TreeNode)(tp.getLastPathComponent());
-            
+
             TreeNode[] childs = tn.getTreeNodes();
             if (childs != null)
             for (int i = 0; i < childs.length; i++)
             treeModel.removeRelevantNode(childs[i]);
-            
+
             TestResult[] trs = tn.getTestResults();
             if (trs != null)
             for (int i = 0; i < trs.length; i++)
@@ -1782,22 +1782,22 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             maybeShowPopup(e);
         }
 
-	private void updateSelection(MouseEvent e) {
-	    TreePath pathClicked = tree.getPathForLocation(e.getX(), e.getY());
-	    if(pathClicked != null && tree.getSelectionCount() <= 1 && tree.getSelectionPath() != pathClicked) {
-		tree.setSelectionPath(pathClicked);
-	    }
-	}
+        private void updateSelection(MouseEvent e) {
+            TreePath pathClicked = tree.getPathForLocation(e.getX(), e.getY());
+            if(pathClicked != null && tree.getSelectionCount() <= 1 && tree.getSelectionPath() != pathClicked) {
+                tree.setSelectionPath(pathClicked);
+            }
+        }
 
         private void maybeShowPopup(MouseEvent e) {
             if (e.isPopupTrigger() && e.getComponent() == tree) {
                 lastX = e.getX();
                 lastY = e.getY();
-		updateSelection(e);
+                updateSelection(e);
                 // filter out clicks which don't hit the tree
-		/*
+                /*
                 TreePath target = tree.getPathForLocation(lastX, lastY);
-                
+
                 if (target != null) {
                 lastPopupPath = target;
                  */
@@ -1843,7 +1843,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                             paths = new TreePath[]{new TreePath(target)};
                             break;
                         }
-                    }	// for
+                    }   // for
                     runNodes(paths);
                 } else {
                     // XXX show error dialog
@@ -1950,9 +1950,9 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             if (tree != null) {
                 TreePath[] p = tree.snapshotOpenPaths();
                 openPaths = treeModel.pathsToStrings(p);
-                
+
                 selectedPaths = treeModel.pathsToStrings(tree.snapshotSelectedPaths());
-                
+
             }
 
             if (treeModel != null) {
@@ -1962,8 +1962,10 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
 
             if (openPaths != null && openPaths.length > 0)
                 tree.restorePaths(openPaths, true);
-            
-            tree.restoreSelection(selectedPaths);
+
+            if (tree != null) {
+                tree.restoreSelection(selectedPaths);
+            }
         }
 
         public void nodeSelected(Object node, TreePath path) {
@@ -2097,7 +2099,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                 }
             }
 
-            tree.repaint();	// we're allowed to call this on any thread
+            tree.repaint();     // we're allowed to call this on any thread
         }
 
         public void finishedTest(TestResult tr) {
@@ -2136,7 +2138,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
                     }
                 }   // for
             }
-            tree.repaint();	// we're allowed to call this on any thread
+            tree.repaint();     // we're allowed to call this on any thread
         }
 
         public void stoppingTestRun() {
@@ -2153,7 +2155,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             purgeMI.setEnabled(true);
             refreshMI.setEnabled(true);
 
-            tree.repaint();	// we're allowed to call this on any thread
+            tree.repaint();     // we're allowed to call this on any thread
         }
 
         public void error(String msg) {
@@ -2164,7 +2166,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             /* BK reenable
             if (treeModel == null || treeModel.getTestResultTable() == null)
             return;
-            
+
             // this is primarily to ensure that the subpanel gets updated when
             // asynchronous (non-user GUI) events occur
             // example - if a "clear" operation is done, which includes the shown test
@@ -2173,7 +2175,7 @@ class TestTreePanel extends JPanel implements ET_TestTreeControl, HarnessAware,
             TestResult lookupTr = treeModel.getTestResultTable().lookup(
             newValue.getWorkRelativePath());
             TreeNode[] nodes = TestResultTable.getObjectPath(lookupTr);
-            
+
             Object[] p = new Object[nodes.length + 1];
             System.arraycopy(nodes, 0, p, 0, nodes.length);
             p[p.length-1] = newValue;
