@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2006, 2009, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2006, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -63,10 +63,11 @@ import javax.swing.text.html.HTMLFrameHyperlinkEvent;
 
 import com.sun.javatest.report.CustomReport;
 import com.sun.javatest.report.Report;
+import com.sun.javatest.report.ReportSettings;
 import com.sun.javatest.tool.Desktop;
 import com.sun.javatest.tool.Tool;
 import com.sun.javatest.tool.ToolManager;
-import com.sun.javatest.util.HTMLWriter;
+import com.sun.javatest.report.HTMLWriterEx;
 import com.sun.javatest.util.I18NResourceBundle;
 import java.awt.Component;
 import java.lang.reflect.InvocationTargetException;
@@ -76,14 +77,14 @@ import javax.swing.Timer;
 import javax.swing.SwingUtilities;
 
 
-class ReportTool extends Tool{
+class ReportTool extends Tool {
 
     // desktop is used to get custom reports
     // for results processing
     private Desktop desktop;
 
     protected ReportTool(ToolManager m, Desktop d) {
-        super(m, "report", "report.window.sch");
+        super(m, "report", "mergeReports.window.csh");
         setI18NTitle("tool.title");
         setShortTitle(uif.getI18NString("tool.shortTitle"));
         this.desktop = d;
@@ -278,8 +279,7 @@ class ReportTool extends Tool{
                                 return ;
                             }
                             CustomReport cr = customReports[i];
-                            CustomReport.ReportEnviroment re = 
-                                    cr.getReportEnviroment();
+                            ReportSettings re = cr.getReportEnviroment();
                             re.setMergingFiles(in);
                             re.setXMLReportFile(xmlOut);
                             cr.createReport(new File(out, cr.getReportId()));
@@ -494,35 +494,36 @@ class ReportTool extends Tool{
         String[] filelist = dir.list();
         StringWriter sw = new StringWriter();
         try {
-            HTMLWriter out = new HTMLWriter(sw, uif.getI18NResourceBundle());
+            HTMLWriterEx out = new HTMLWriterEx(sw, uif.getI18NResourceBundle());
 
-            out.startTag(HTMLWriter.HTML);
-            out.startTag(HTMLWriter.HEAD);
-            out.startTag(HTMLWriter.TITLE);
+            out.startTag(HTMLWriterEx.HTML);
+            out.startTag(HTMLWriterEx.HEAD);
+            out.writeContentMeta();
+            out.startTag(HTMLWriterEx.TITLE);
             out.write(displayPath);
-            out.endTag(HTMLWriter.TITLE);
-            out.endTag(HTMLWriter.HEAD);
-            out.startTag(HTMLWriter.BODY);
+            out.endTag(HTMLWriterEx.TITLE);
+            out.endTag(HTMLWriterEx.HEAD);
+            out.startTag(HTMLWriterEx.BODY);
             out.writeStyleAttr("font-family: SansSerif; font-size: 12pt");
-            out.startTag(HTMLWriter.H3);
+            out.startTag(HTMLWriterEx.H3);
             out.writeI18N("fp.head", displayPath);
-            out.endTag(HTMLWriter.H3);
-            out.startTag(HTMLWriter.UL);
+            out.endTag(HTMLWriterEx.H3);
+            out.startTag(HTMLWriterEx.UL);
             out.writeStyleAttr("margin-left:0");
 
             File parent = dir.getParentFile();
             if (parent != null) {
-                out.startTag(HTMLWriter.LI);
-                out.startTag(HTMLWriter.OBJECT);
-                out.writeAttr(HTMLWriter.CLASSID, "com.sun.javatest.tool.IconLabel");
+                out.startTag(HTMLWriterEx.LI);
+                out.startTag(HTMLWriterEx.OBJECT);
+                out.writeAttr(HTMLWriterEx.CLASSID, "com.sun.javatest.tool.IconLabel");
                 out.writeParam("type", "up");
-                out.endTag(HTMLWriter.OBJECT);
+                out.endTag(HTMLWriterEx.OBJECT);
                 out.writeEntity("&nbsp;");
                 try {
-                    out.startTag(HTMLWriter.A);
-                    out.writeAttr(HTMLWriter.HREF, parent.toURL().toString());
+                    out.startTag(HTMLWriterEx.A);
+                    out.writeAttr(HTMLWriterEx.HREF, parent.toURL().toString());
                     out.writeI18N("fp.parent");
-                    out.endTag(HTMLWriter.A);
+                    out.endTag(HTMLWriterEx.A);
                 } catch (MalformedURLException e) {
                     out.writeI18N("fp.parent");
                 }
@@ -530,11 +531,11 @@ class ReportTool extends Tool{
 
             for (int i = 0; i < filelist.length; i++) {
                 File file = new File(dir, filelist[i]);
-                out.startTag(HTMLWriter.LI);
-                out.startTag(HTMLWriter.OBJECT);
-                out.writeAttr(HTMLWriter.CLASSID, "com.sun.javatest.tool.IconLabel");
+                out.startTag(HTMLWriterEx.LI);
+                out.startTag(HTMLWriterEx.OBJECT);
+                out.writeAttr(HTMLWriterEx.CLASSID, "com.sun.javatest.tool.IconLabel");
                 out.writeParam("type", (file.isDirectory() ? "folder" : "file"));
-                out.endTag(HTMLWriter.OBJECT);
+                out.endTag(HTMLWriterEx.OBJECT);
                 out.writeEntity("&nbsp;");
                 try {
                     out.writeLink(file.toURL(), file.getName());
@@ -543,9 +544,9 @@ class ReportTool extends Tool{
                 }
             }
 
-            out.endTag(HTMLWriter.UL);
-            out.endTag(HTMLWriter.BODY);
-            out.endTag(HTMLWriter.HTML);
+            out.endTag(HTMLWriterEx.UL);
+            out.endTag(HTMLWriterEx.BODY);
+            out.endTag(HTMLWriterEx.HTML);
             out.close();
         } catch (IOException e) {
             // should not happen, writing to StringWriter
@@ -606,7 +607,7 @@ class ReportTool extends Tool{
     private BrowserPane browserPane;
     private JDialog waitDialog;
     private WaitDialogController waitDialogController;
-    private static final int WAIT_DIALOG_DELAY = 3000;	    // 3 second delay
+    private static final int WAIT_DIALOG_DELAY = 3000;      // 3 second delay
 
     // The merge options
     private File[] in;
