@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,7 +38,6 @@ import com.sun.javatest.KnownFailuresList;
 import com.sun.javatest.TestResult;
 import com.sun.javatest.TestResultTable;
 import com.sun.javatest.tool.Preferences;
-import com.sun.javatest.util.HTMLWriter;
 import com.sun.javatest.util.I18NResourceBundle;
 
 /**
@@ -47,22 +46,23 @@ import com.sun.javatest.util.I18NResourceBundle;
  */
 class KflSection extends HTMLSection {
 
-    KflSection(HTMLReport parent, Report.Settings settings, File dir, I18NResourceBundle i18n) {
+    KflSection(HTMLReport parent, ReportSettings settings, File dir, I18NResourceBundle i18n,
+            KflSorter data) {
         super(i18n.getString("kfl.title"), settings, dir, parent);
         this.i18n = i18n;
+        sorter = data;
 
-        resultTable = settings.ip.getWorkDirectory().getTestResultTable();
-        kfl = settings.ip.getKnownFailuresList();
-        workDirRoot = settings.ip.getWorkDirectory().getRoot();
+        resultTable = settings.getInterview().getWorkDirectory().getTestResultTable();
+        kfl = settings.getInterview().getKnownFailuresList();
 
         i18n.getString("kfl.f2e.heading");
         i18n.getString("kfl.f2e.notes");
         i18n.getString("kfl.f2e.title");
-        
+
         i18n.getString("kfl.f2m.heading");
         i18n.getString("kfl.f2m.notes");
         i18n.getString("kfl.f2m.title");
-        
+
         i18n.getString("kfl.f2nr.heading");
         i18n.getString("kfl.f2nr.notes");
         i18n.getString("kfl.f2nr.title");
@@ -70,7 +70,7 @@ class KflSection extends HTMLSection {
         i18n.getString("kfl.f2p.heading");
         i18n.getString("kfl.f2p.notes");
         i18n.getString("kfl.f2p.title");
-        
+
         i18n.getString("kfl.new.heading");
         i18n.getString("kfl.new.notes");
         i18n.getString("kfl.new.title");
@@ -78,36 +78,35 @@ class KflSection extends HTMLSection {
         i18n.getString("kfl.errors.heading");
         i18n.getString("kfl.errors.notes");
         i18n.getString("kfl.errors.title");
-        
+
         i18n.getString("kfl.f2f.heading");
         i18n.getString("kfl.f2f.notes");
         i18n.getString("kfl.f2f.title");
-        
+
         i18n.getString("kfl.tc_f2e.heading");
         i18n.getString("kfl.tc_f2e.notes");
         i18n.getString("kfl.tc_f2e.summary");
         i18n.getString("kfl.tc_f2e.title");
-        
+
         i18n.getString("kfl.tc_f2m.heading");
         i18n.getString("kfl.tc_f2m.notes");
         i18n.getString("kfl.tc_f2m.summary");
         i18n.getString("kfl.tc_f2m.title");
-        
+
         i18n.getString("kfl.tc_f2nr.heading");
         i18n.getString("kfl.tc_f2nr.notes");
         i18n.getString("kfl.tc_f2nr.summary");
         i18n.getString("kfl.tc_f2nr.title");
-        
+
         i18n.getString("kfl.tc_f2p.heading");
         i18n.getString("kfl.tc_f2p.notes");
         i18n.getString("kfl.tc_f2p.summary");
         i18n.getString("kfl.tc_f2p.title");
-        
+
         i18n.getString("kfl.tc_new.heading");
         i18n.getString("kfl.tc_new.notes");
         i18n.getString("kfl.tc_new.summary");
         i18n.getString("kfl.tc_new.title");
-        
     }
 
     @Override
@@ -115,17 +114,17 @@ class KflSection extends HTMLSection {
         super.writeSummary(out);
 
         out.write(i18n.getString("kfl.files.list"));
-        File[] kfls = settings.ip.getKnownFailureFiles();
+        File[] kfls = settings.getInterview().getKnownFailureFiles();
 
         if (kfls != null && kfls.length > 0) {
-            out.startTag(HTMLWriter.UL);
+            out.startTag(HTMLWriterEx.UL);
 
             for (File f : kfls) {
-                out.startTag(HTMLWriter.LI);
+                out.startTag(HTMLWriterEx.LI);
                 out.writeLink(f.toURI().toString(), f.getCanonicalPath());
             }   // for
 
-            out.endTag(HTMLWriter.UL);
+            out.endTag(HTMLWriterEx.UL);
         } else {
             out.write(i18n.getString("kfl.nofiles"));
             out.newLine();
@@ -133,135 +132,137 @@ class KflSection extends HTMLSection {
         }
 
         if (kfl == null) {
-            out.startTag(HTMLWriter.P);
+            out.startTag(HTMLWriterEx.P);
             out.write(i18n.getString("kfl.unable"));
-            out.startTag(HTMLWriter.BR);
+            out.startTag(HTMLWriterEx.BR);
             out.newLine();
             return;
         }
 
+        /*
         sorter = new KflSorter(kfl, resultTable, settings.isKflTestCasesEnabled());
         sorter.setF2eEnabled(settings.isKflF2eEnabled());
         sorter.setF2fEnabled(settings.isKflF2fEnabled());
         sorter.setMissingEnabled(settings.isKflMissingEnabled());
-        
+
         int errors = sorter.run(parent.getResults());
+         */
 
-        out.startTag(HTMLWriter.TABLE);
-        out.writeAttr(HTMLWriter.BORDER, 1);
+        out.startTag(HTMLWriterEx.TABLE);
+        out.writeAttr(HTMLWriterEx.BORDER, 1);
 
-        out.startTag(HTMLWriter.TR);
-        out.writeTH(i18n.getString("kfl.changes.hdr"), HTMLWriter.ROW);
-        out.writeTH(i18n.getString("kfl.tests.hdr", Integer.toString(errors)), HTMLWriter.ROW);
+        out.startTag(HTMLWriterEx.TR);
+        out.writeTH(i18n.getString("kfl.changes.hdr"), HTMLWriterEx.ROW);
+        out.writeTH(i18n.getString("kfl.tests.hdr", Integer.toString(sorter.getErrorCount())), HTMLWriterEx.ROW);
 
         if (settings.isKflTestCasesEnabled()) {
-            out.writeTH(i18n.getString("kfl.tc.hdr", Integer.toString(sorter.getTestCasesErrorCount())), HTMLWriter.ROW);
+            out.writeTH(i18n.getString("kfl.tc.hdr", Integer.toString(sorter.getTestCasesErrorCount())), HTMLWriterEx.ROW);
         }
 
         // FAIL to PASS
-        out.startTag(HTMLWriter.TR);
-        out.writeTH(i18n.getString("kfl.f2p.summary"), HTMLWriter.ROW);
+        out.startTag(HTMLWriterEx.TR);
+        out.writeTH(i18n.getString("kfl.f2p.summary"), HTMLWriterEx.ROW);
 
-        out.startTag(HTMLWriter.TD);
+        out.startTag(HTMLWriterEx.TD);
         out.writeLink(FAIL2PASS, Integer.toString(sorter.getSet(KflSorter.Transitions.FAIL2PASS).size()));
-        out.endTag(HTMLWriter.TD);
+        out.endTag(HTMLWriterEx.TD);
 
         if (settings.isKflTestCasesEnabled()) {
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(TC_FAIL2PASS, Integer.toString(sorter.getSet(KflSorter.Transitions.TC_FAIL2PASS).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
         }
 
         // FAIL to ERROR
         if (settings.isKflF2eEnabled()) {
-            out.startTag(HTMLWriter.TR);
-            out.writeTH(i18n.getString("kfl.f2e.summary"), HTMLWriter.ROW);
+            out.startTag(HTMLWriterEx.TR);
+            out.writeTH(i18n.getString("kfl.f2e.summary"), HTMLWriterEx.ROW);
 
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(FAIL2ERROR, Integer.toString(sorter.getSet(KflSorter.Transitions.FAIL2ERROR).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
 
             if (settings.isKflTestCasesEnabled()) {
-                out.startTag(HTMLWriter.TD);
+                out.startTag(HTMLWriterEx.TD);
                 out.writeLink(TC_FAIL2ERROR, Integer.toString(sorter.getSet(KflSorter.Transitions.TC_FAIL2ERROR).size()));
-                out.endTag(HTMLWriter.TD);
+                out.endTag(HTMLWriterEx.TD);
             }
         }
 
         // UNRELATED ERRORS
-        out.startTag(HTMLWriter.TR);
-        out.writeTH(i18n.getString("kfl.errors.summary"), HTMLWriter.ROW);
+        out.startTag(HTMLWriterEx.TR);
+        out.writeTH(i18n.getString("kfl.errors.summary"), HTMLWriterEx.ROW);
 
-        out.startTag(HTMLWriter.TD);
+        out.startTag(HTMLWriterEx.TD);
         out.writeLink(OTHER_ERRORS, Integer.toString(sorter.getSet(KflSorter.Transitions.OTHER_ERRORS).size()));
-        out.endTag(HTMLWriter.TD);
+        out.endTag(HTMLWriterEx.TD);
 
         // print that no TC info is available
-        out.startTag(HTMLWriter.TD);
+        out.startTag(HTMLWriterEx.TD);
         out.write(i18n.getString("kfl.f2f.notc"));
-        out.endTag(HTMLWriter.TD);
+        out.endTag(HTMLWriterEx.TD);
 
         // FAIL to NOT RUN
-        out.startTag(HTMLWriter.TR);
-        out.writeTH(i18n.getString("kfl.f2nr.summary"), HTMLWriter.ROW);
+        out.startTag(HTMLWriterEx.TR);
+        out.writeTH(i18n.getString("kfl.f2nr.summary"), HTMLWriterEx.ROW);
 
-        out.startTag(HTMLWriter.TD);
+        out.startTag(HTMLWriterEx.TD);
         out.writeLink(FAIL2NOTRUN, Integer.toString(sorter.getSet(KflSorter.Transitions.FAIL2NOTRUN).size()));
-        out.endTag(HTMLWriter.TD);
+        out.endTag(HTMLWriterEx.TD);
 
         if (settings.isKflTestCasesEnabled()) {
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(TC_FAIL2NOTRUN, Integer.toString(sorter.getSet(KflSorter.Transitions.TC_FAIL2NOTRUN).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
         }
 
         if (settings.isKflMissingEnabled()) {
-            out.startTag(HTMLWriter.TR);
-            out.writeTH(i18n.getString("kfl.f2m.summary"), HTMLWriter.ROW);
+            out.startTag(HTMLWriterEx.TR);
+            out.writeTH(i18n.getString("kfl.f2m.summary"), HTMLWriterEx.ROW);
 
             // FAIL to MISSING
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(FAIL2MISSING, Integer.toString(sorter.getSet(KflSorter.Transitions.FAIL2MISSING).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
 
             if (settings.isKflTestCasesEnabled()) {
-                out.startTag(HTMLWriter.TD);
+                out.startTag(HTMLWriterEx.TD);
                 out.writeLink(TC_FAIL2MISSING, Integer.toString(sorter.getSet(KflSorter.Transitions.TC_FAIL2MISSING).size()));
-                out.endTag(HTMLWriter.TD);
+                out.endTag(HTMLWriterEx.TD);
             }
         }
 
         // NEW FAILURES
-        out.startTag(HTMLWriter.TR);
-        out.writeTH(i18n.getString("kfl.new.summary"), HTMLWriter.ROW);
-        out.startTag(HTMLWriter.TD);
+        out.startTag(HTMLWriterEx.TR);
+        out.writeTH(i18n.getString("kfl.new.summary"), HTMLWriterEx.ROW);
+        out.startTag(HTMLWriterEx.TD);
         out.writeLink(NEWFAILURES, Integer.toString(sorter.getSet(KflSorter.Transitions.NEWFAILURES).size()));
-        out.endTag(HTMLWriter.TD);
+        out.endTag(HTMLWriterEx.TD);
 
         if (settings.isKflTestCasesEnabled()) {
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(TC_NEWFAILURES, Integer.toString(sorter.getSet(KflSorter.Transitions.TC_NEWFAILURES).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
         }
 
-        out.endTag(HTMLWriter.TR);
+        out.endTag(HTMLWriterEx.TR);
 
         // FAIL to FAIL
         if (settings.isKflF2fEnabled()) {
-            out.startTag(HTMLWriter.TR);
-            out.writeTH(i18n.getString("kfl.f2f.summary"), HTMLWriter.ROW);
-            out.startTag(HTMLWriter.TD);
+            out.startTag(HTMLWriterEx.TR);
+            out.writeTH(i18n.getString("kfl.f2f.summary"), HTMLWriterEx.ROW);
+            out.startTag(HTMLWriterEx.TD);
             out.writeLink(FAIL2FAIL, Integer.toString(sorter.getSet(KflSorter.Transitions.FAIL2FAIL).size()));
-            out.endTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
 
             if (settings.isKflTestCasesEnabled()) {
-                out.startTag(HTMLWriter.TD);
+                out.startTag(HTMLWriterEx.TD);
                 out.write(i18n.getString("kfl.f2f.notc"));
-                out.endTag(HTMLWriter.TD);
+                out.endTag(HTMLWriterEx.TD);
             }
         }
 
-        out.endTag(HTMLWriter.TABLE);
+        out.endTag(HTMLWriterEx.TABLE);
     }
 
     @Override
@@ -291,7 +292,7 @@ class KflSection extends HTMLSection {
     void writeSet(String file, String prefix, SortedSet<KflSorter.TestDiff> tests) throws IOException {
         ReportWriter out = new ReportWriter(openWriter(file), i18n.getString(prefix + ".title"), i18n);
         out.write(i18n.getString(prefix + ".notes"));
-        out.startTag(HTMLWriter.P);
+        out.startTag(HTMLWriterEx.P);
 
         if (tests == null || tests.size() == 0) {
             out.write(i18n.getString("kfl.noItemsInSet"));
@@ -300,28 +301,28 @@ class KflSection extends HTMLSection {
             return;
         }
 
-        out.startTag(HTMLWriter.TABLE);
+        out.startTag(HTMLWriterEx.TABLE);
         out.writeAttr("border", "1");
-        out.startTag(HTMLWriter.TR);
-        out.startTag(HTMLWriter.TH);
+        out.startTag(HTMLWriterEx.TR);
+        out.startTag(HTMLWriterEx.TH);
         out.write(i18n.getString("kfl.table.bugs.txt"));
-        out.endTag(HTMLWriter.TH);
-        out.startTag(HTMLWriter.TH);
+        out.endTag(HTMLWriterEx.TH);
+        out.startTag(HTMLWriterEx.TH);
         out.write(i18n.getString("kfl.table.URL.txt"));
-        out.endTag(HTMLWriter.TH);
-        out.endTag(HTMLWriter.TR);
+        out.endTag(HTMLWriterEx.TH);
+        out.endTag(HTMLWriterEx.TR);
 
         for (KflSorter.TestDiff diff : tests) {
             TestResult tr = diff.getTestResult();
 
-            out.startTag(HTMLWriter.TR);
-            out.startTag(HTMLWriter.TD);
-            
+            out.startTag(HTMLWriterEx.TR);
+            out.startTag(HTMLWriterEx.TD);
+
             writeBugs(diff, out);
             out.newLine();
 
-            out.endTag(HTMLWriter.TD);
-            out.startTag(HTMLWriter.TD);
+            out.endTag(HTMLWriterEx.TD);
+            out.startTag(HTMLWriterEx.TD);
 
             if (tr != null && tr.isReloadable()) {
                 String eWRPath = tr.getWorkRelativePath();
@@ -333,12 +334,12 @@ class KflSection extends HTMLSection {
                 out.write(diff.getName());
             }
 
-            out.endTag(HTMLWriter.TD);
-            out.endTag(HTMLWriter.TR);
+            out.endTag(HTMLWriterEx.TD);
+            out.endTag(HTMLWriterEx.TR);
 
         }   // for
 
-        out.endTag(HTMLWriter.TABLE);
+        out.endTag(HTMLWriterEx.TABLE);
         out.close();
     }
 
@@ -485,19 +486,19 @@ class KflSection extends HTMLSection {
     currentHead = e_s.getReason();
     if (inList) {
     inList = false;
-    out.endTag(HTMLWriter.UL);
+    out.endTag(HTMLWriterEx.UL);
     out.newLine();
     }
-    out.startTag(HTMLWriter.H4);
+    out.startTag(HTMLWriterEx.H4);
     out.write(currentHead.length() == 0 ? i18n.getString("result.noReason") : currentHead);
-    out.endTag(HTMLWriter.H4);
+    out.endTag(HTMLWriterEx.H4);
     out.newLine();
     }
     if (!inList) {
     inList = true;
-    out.startTag(HTMLWriter.UL);
+    out.startTag(HTMLWriterEx.UL);
     }
-    out.startTag(HTMLWriter.LI);
+    out.startTag(HTMLWriterEx.LI);
 
     //File eFile = e.getFile();
     String eWRPath = e.getWorkRelativePath();
@@ -514,7 +515,7 @@ class KflSection extends HTMLSection {
     }
     if (inList) {
     inList = false;
-    out.endTag(HTMLWriter.UL);
+    out.endTag(HTMLWriterEx.UL);
     }
     }
     }
@@ -524,13 +525,12 @@ class KflSection extends HTMLSection {
     }
     }
      */
-    private File workDirRoot;
     private TestResultTable resultTable;
     private KflSorter sorter;
     private KnownFailuresList kfl;
-    
+
     private final I18NResourceBundle i18n;
-    
+
     static final String FAIL2PASS = "kfl_fail2pass.html";
     static final String FAIL2ERROR = "kfl_fail2error.html";
     static final String FAIL2MISSING = "kfl_fail2missing.html";
