@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,21 +26,20 @@
  */
 package com.sun.javatest.report;
 
-import java.io.BufferedReader;
-import java.io.IOException;
-import java.io.StringReader;
-import java.util.LinkedHashMap;
-import java.util.Iterator;
-import java.util.Map;
-import java.util.TreeSet;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
 import com.sun.javatest.KnownFailuresList;
 import com.sun.javatest.Status;
 import com.sun.javatest.TestResult;
 import com.sun.javatest.TestResultTable;
 import com.sun.javatest.util.StringArray;
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.StringReader;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+import java.util.Map;
+import java.util.TreeSet;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 /**
  * Support class to read and process a list of tests and test cases which are
@@ -215,12 +214,12 @@ public class KflSorter {
             }
             else if (enableTestCases && tr.getStatus().isFailed()) {
                 // FAILED test on KFL
-                
+
                 // look for new test cases which might be passing
                 // easy to do here because we are iterating the KFL
                 //tcprobs += findChangedCases(tr, tcs, entry);
             }
-        }
+        }   // for
 
         // iterate failures, are they on the KFL?
         for(Object o: tests[Status.FAILED]) {
@@ -267,6 +266,16 @@ public class KflSorter {
                                                 name, tr, Transitions.TC_NEWFAILURES);
                                     if(tc_newFailures.add(td))
                                         tcprobs++;
+
+                                    // could optimize slightly to avoid repeated
+                                    // adds if multiple test cases are new fails.
+                                    // ensures that a tc-only differnece is also
+                                    // reported in the non-tc new failures list
+                                    TestDiff diff = new TestDiff(tr.getTestName(), tr,
+                                            Transitions.NEWFAILURES);
+                                    if (newFailures.add(diff)) {
+                                        probs++;
+                                    }
                                 }
                                 break;
                             case Status.PASSED:
@@ -424,7 +433,7 @@ public class KflSorter {
             return 0;
 
         for (String s: tcs) {
-        
+
         }
 
         return problems;
@@ -498,7 +507,7 @@ public class KflSorter {
                 // could be a new test case, etc.
                 if (!fullTestListed && e == null)
                     continue;
-                
+
                 if (stat.getType() == status) {
                     TestDiff diff = new TestDiff(url, key, tr, t);
                     if (fullTestListed && full != null && full.length > 0)
@@ -685,23 +694,23 @@ public class KflSorter {
         }
 
         @Override
-	public int compareTo(Object o) {
-	    TestDiff e = (TestDiff) o;
-	    int n = getName().compareTo(e.getName());
-/*	    if (n == 0) {
-		if (testCase == null && e.testCase == null)
-		    return 0;
-		else if (testCase == null)
-		    return -1;
-		else if (e.testCase == null)
-		    return +1;
-		else
-		    return testCase.compareTo(e.testCase);
-	    }
-	    else
-		return n;*/
+        public int compareTo(Object o) {
+            TestDiff e = (TestDiff) o;
+            int n = getName().compareTo(e.getName());
+/*          if (n == 0) {
+                if (testCase == null && e.testCase == null)
+                    return 0;
+                else if (testCase == null)
+                    return -1;
+                else if (e.testCase == null)
+                    return +1;
+                else
+                    return testCase.compareTo(e.testCase);
+            }
+            else
+                return n;*/
             return n;
-	}
+        }
 
         private TestResult tr;
         private String url;
