@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2006, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2006, 2012, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -48,21 +48,21 @@ import com.sun.javatest.TestResult;
 import com.sun.javatest.TestResult.Section;
 import com.sun.javatest.TestResultTable;
 import com.sun.javatest.WorkDirectory;
-import com.sun.javatest.util.BackupPolicy;
-
-import java.io.File;
-import java.io.IOException;
 import com.sun.javatest.util.I18NResourceBundle;
 import java.io.BufferedWriter;
+import java.io.File;
 import java.io.FileOutputStream;
+import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.text.DateFormat;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
 import org.xml.sax.SAXException;
 
@@ -70,12 +70,11 @@ import org.xml.sax.SAXException;
 /**
  * XML report (dump).
  */
-class XMLReport  {
-    
-    public void write(CustomReport.ReportEnviroment sett, File dir) throws IOException {
-        
-        BackupPolicy backupPolicy;
-        
+public class XMLReport  implements ReportFormat {
+
+    @Override
+    public ReportLink write(ReportSettings sett, File dir) throws IOException {
+
         File repFile = new File(dir, REPORT_NAME);
         Writer w = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(repFile), XMLReportMaker.XML_CHARSET));
         try {
@@ -84,47 +83,75 @@ class XMLReport  {
             throw new JavaTestError(i18n.getString("report.writing.err"), ex);
         }
         w.close();
-        sett.xmlReportFile = repFile; 
-        
+        sett.xmlReportFile = repFile;
+
+        return new ReportLink(i18n.getString("index.xmltype.txt"),
+                getBaseDirName(), i18n.getString("index.desc.xml"),repFile);
+
     }
-    
-    public void write(Writer w, CustomReport.ReportEnviroment sett) throws IOException, SAXException {
-        
+
+    @Override
+    public String getReportID() {
+        return ID;
+    }
+
+    @Override
+    public String getBaseDirName() {
+        return ID;
+    }
+
+    @Override
+    public String getTypeName() {
+        return ID;
+    }
+
+    @Override
+    public boolean acceptSettings(ReportSettings s) {
+        return s.isXmlEnabled();
+    }
+
+    @Override
+    public List<ReportFormat> getSubReports() {
+        return Collections.<ReportFormat>emptyList();
+    }
+
+    public void write(Writer w, ReportSettings sett) throws IOException, SAXException {
+
         XMLReportMaker maker = new XMLReportMaker(w);
         maker.sDocument();
         maker.sReport();
         maker.sWorkdirectories();
         File jti = null;
-        if (sett.getIp() != null) {
-            jti = sett.getIp().getFile();
+        if (sett.getInterview() != null) {
+            jti = sett.getInterview().getFile();
         }
         maker.sWorkdirectory( jti == null ? null : jti.getPath());
-        
+
         writeTemplateInfo(maker, sett);
         writeInterview(maker, sett);
         writeStandardValues(maker, sett);
         writeEnvironment(maker, sett);
-        
+
         maker.eWorkdirectory();
         maker.eWorkdirectories();
         writeResults(maker, sett);
         maker.eReport();
         maker.eDocument();
-        
+
     }
-    
-    private void writeResults(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException, JavaTestError, IOException {
+
+    private void writeResults(final XMLReportMaker maker, final ReportSettings sett) throws SAXException, JavaTestError, IOException {
         maker.sTestResults();
-        
-        File[] initFiles = sett.getInitFiles();
+
+        File[] initFiles = sett.getInitialFiles();
         Iterator iter = null;
-        TestResultTable resultTable = sett.getIp().getWorkDirectory().getTestResultTable();
-        
+        TestResultTable resultTable = sett.getInterview().getWorkDirectory().getTestResultTable();
+
         try {
             if (initFiles == null) {
-                iter = resultTable.getIterator(new TestFilter[] {sett.getFilter()});
+                iter = resultTable.getIterator(new TestFilter[] {sett.getTestFilter()});
             } else {
-                iter = resultTable.getIterator(initFiles, new TestFilter[] {sett.getFilter()});
+                iter = resultTable.getIterator(initFiles, new TestFilter[] {sett.getTestFilter()});
             }
             for (; iter.hasNext(); ) {
                 TestResult tr = (TestResult) (iter.next());
@@ -135,9 +162,9 @@ class XMLReport  {
             throw new JavaTestError(i18n.getString("report.testResult.err"), f);
         }
     }
-    
+
     private void writeResult(final XMLReportMaker maker, final TestResult testResult) throws SAXException, IOException {
-        
+
         maker.sTestResult(testResult.getTestName(), testResult.getStatus(), 1);
         try {
             writeDescriptionData(maker, testResult);
@@ -152,9 +179,9 @@ class XMLReport  {
             maker.eTestResult();
         }
     }
-    
+
     private void writeSections(final XMLReportMaker maker, final TestResult testResult) throws SAXException, IOException, TestResult.Fault {
-        
+
         maker.sSections();
         for (int i = 0; i < testResult.getSectionCount() ; i++) {
             String st = testResult.getSectionTitles()[i];
@@ -170,11 +197,11 @@ class XMLReport  {
         }
         maker.eSections();
     }
-    
+
     private void writeResultProps(final XMLReportMaker maker, final TestResult testResult) throws SAXException, TestResult.Fault {
-        
+
         String time = testResult.getProperty(TestResult.END);
-        
+
         maker.sResultProps(time);
         Enumeration en = testResult.getPropertyNames();
         while (en.hasMoreElements()) {
@@ -186,9 +213,9 @@ class XMLReport  {
         }
         maker.eResultProps();
     }
-    
+
     private void writeEnvironment(final XMLReportMaker maker, final TestResult testResult) throws SAXException {
-        
+
         Iterator keysIt;
         try {
             Map m = testResult.getEnvironment();
@@ -201,19 +228,19 @@ class XMLReport  {
             }
             maker.eTestEnvironment();
         } catch (TestResult.Fault e) {
-            
+
         }
     }
-    
+
     private void writeDescriptionData(final XMLReportMaker maker, final TestResult testResult) throws SAXException, TestResult.Fault {
         maker.sDescriptionData();
-        
+
         TestDescription td = testResult.getDescription();
         Iterator keysIt = td.getParameterKeys();
-        
+
         maker.makeProperty("$root", td.getRootDir());
         maker.makeProperty("$file", td.getFile().getPath());
-        
+
         while (keysIt.hasNext()) {
             String key = (String) keysIt.next();
             // dump keywords separately
@@ -222,7 +249,7 @@ class XMLReport  {
                 maker.makeProperty(key, val);
             }
         }
-        
+
         String [] kws = td.getKeywords();
         if (kws != null && kws.length > 0 ) {
             maker.sKeyWords();
@@ -231,22 +258,22 @@ class XMLReport  {
         }
         maker.eDescriptionData();
     }
-    
+
     private void writeAnnotations(XMLReportMaker maker, TestResult testResult) throws SAXException {
         TestResultTable.TreeNode tn = testResult.getParent();
         TestResultTable trt = null;
         WorkDirectory wd = null;
-        
+
         if (tn != null)
             trt = tn.getEnclosingTable();
         else
             return;
-        
+
         if (trt != null)
             wd = trt.getWorkDirectory();
         else
             return;
-        
+
         Map<String,String> map = wd.getTestAnnotations(testResult);
         if (map != null) {
             maker.sTAnnotationData();
@@ -256,18 +283,18 @@ class XMLReport  {
             maker.eTAnnotationData();
         }
     }
-    
-    private void writeEnvironment(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
-        
+
+    private void writeEnvironment(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
+
         String name = null, descr = null;
-        
-        if (sett.getIp().getEnv() != null) {
-            name = sett.getIp().getEnv().getName();
-            descr= sett.getIp().getEnv().getDescription();
+
+        if (sett.getInterview().getEnv() != null) {
+            name = sett.getInterview().getEnv().getName();
+            descr= sett.getInterview().getEnv().getDescription();
         }
-        
+
         maker.sEnvironment(name, descr);
-        TestEnvironment env = sett.getIp().getEnv();
+        TestEnvironment env = sett.getInterview().getEnv();
         if (env != null) {
             for (Iterator i = env.elements().iterator(); i.hasNext(); ) {
                 TestEnvironment.Element envElem = (TestEnvironment.Element) (i.next());
@@ -276,37 +303,37 @@ class XMLReport  {
         }
         maker.eEnvironment();
     }
-    
-    private void writeStandardValues(final XMLReportMaker maker, CustomReport.ReportEnviroment sett) throws SAXException {
+
+    private void writeStandardValues(final XMLReportMaker maker, ReportSettings sett) throws SAXException {
         maker.sStdValues();
         writeTestsToRun(maker, sett);
         writePriorStatusList(maker, sett);
         writeExcludeLists(maker, sett);
-        maker.conCur(sett.getIp().getConcurrency());
-        maker.timeOut(sett.getIp().getTimeoutFactor());
+        maker.conCur(sett.getInterview().getConcurrency());
+        maker.timeOut(sett.getInterview().getTimeoutFactor());
         writeKeyWords(maker, sett);
         maker.eStdValues();
     }
-    
-    private void writeKeyWords(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
+
+    private void writeKeyWords(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
         // keywords
-        Keywords keywords = sett.getIp().getKeywords();
+        Keywords keywords = sett.getInterview().getKeywords();
         if (keywords != null) {
-            maker.sKeyWords(sett.getIp().getKeywords().toString());
+            maker.sKeyWords(sett.getInterview().getKeywords().toString());
             maker.eKeyWords();
         }
     }
-    
-    private void writeExcludeLists(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
+
+    private void writeExcludeLists(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
         // Exclude
-        ExcludeList excludeList = sett.getIp().getExcludeList();
+        ExcludeList excludeList = sett.getInterview().getExcludeList();
         if (excludeList != null) {
-            Parameters.ExcludeListParameters exclParams = sett.getIp().getExcludeListParameters();
+            Parameters.ExcludeListParameters exclParams = sett.getInterview().getExcludeListParameters();
             File[] excludeFiles = null;
             if (exclParams instanceof Parameters.MutableExcludeListParameters)
                 excludeFiles =
                         ((Parameters.MutableExcludeListParameters) (exclParams)).getExcludeFiles();
-            
+
             if (excludeFiles != null && excludeFiles.length > 0) {
                 maker.sExclList();
                 maker.makeItems(excludeFiles);
@@ -314,9 +341,9 @@ class XMLReport  {
             }
         }
     }
-    
-    private void writePriorStatusList(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
-        boolean[] b = sett.getIp().getPriorStatusValues();
+
+    private void writePriorStatusList(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
+        boolean[] b = sett.getInterview().getPriorStatusValues();
         if (b != null) {
             int[] ss = {Status.PASSED, Status.FAILED, Status.ERROR, Status.NOT_RUN};
             maker.sPriorStatusList();
@@ -328,10 +355,10 @@ class XMLReport  {
             maker.ePriorStatusList();
         }
     }
-    
-    private void writeTestsToRun(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
+
+    private void writeTestsToRun(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
         maker.sTests();
-        String [] tests = sett.getIp().getTests();
+        String [] tests = sett.getInterview().getTests();
         if (tests != null && tests.length > 0) {
             for (int i = 0; i < tests.length; i++) {
                 maker.makeItem(tests[i]);
@@ -342,8 +369,8 @@ class XMLReport  {
         maker.eTests();
     }
 
-    private void writeTemplateInfo(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
-        String tPath = sett.getIp().getTemplatePath();
+    private void writeTemplateInfo(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
+        String tPath = sett.getInterview().getTemplatePath();
         if (tPath != null) {
             try {
                 ConfigInfo ci = TemplateUtilities.getConfigInfo(new File(tPath));
@@ -353,12 +380,12 @@ class XMLReport  {
             }
         }
     }
-    
-    
-    private void writeInterview(final XMLReportMaker maker, final CustomReport.ReportEnviroment sett) throws SAXException {
-        
+
+
+    private void writeInterview(final XMLReportMaker maker, final ReportSettings sett) throws SAXException {
+
         maker.sInterview();
-        Question [] questions = sett.getIp().getPath();
+        Question [] questions = sett.getInterview().getPath();
         for (int i = 0; i < questions.length; i++) {
             Question q = questions[i];
             maker.sQuestion(q.getStringValue(), q.getText(), q.getSummary());
@@ -373,7 +400,7 @@ class XMLReport  {
         }
         maker.eInterview();
     }
-    
+
     private void writeListQuestion(XMLReportMaker maker, Question q) throws SAXException {
         maker.sListQuestion();
         if (q instanceof TreeQuestion) {
@@ -388,7 +415,7 @@ class XMLReport  {
         }
         maker.eListQuestion();
     }
-    
+
     private void writePropertiesQuestion(XMLReportMaker maker, Question q) throws SAXException {
         maker.sPropertiesQuestion();
         PropertiesQuestion pq = (PropertiesQuestion) q;
@@ -408,7 +435,7 @@ class XMLReport  {
         }
         maker.ePropertiesQuestion();
     }
-    
+
     private void writeChoiceQuestion(XMLReportMaker maker, Question q) throws SAXException {
         maker.sChoiceQuestion();
         if (q instanceof ChoiceQuestion ) {
@@ -423,20 +450,20 @@ class XMLReport  {
         }
         maker.eChoiceQuestion();
     }
-    
+
     private void writeTable(XMLReportMaker maker, String[][] table) throws SAXException {
         if (table != null ) {
-            for (int i=0 ; i < table.length ;i++) { 
+            for (int i=0 ; i < table.length ;i++) {
                 maker.makeRow(table[i][0], table[i][1]);
             }
         }
     }
-    
+
     /**
      * Utility class
      */
     static class Utils {
-        
+
         /**
          * Convert date to string in ISO-8601 or xs:dateTime format
          * @param date Date
@@ -449,7 +476,7 @@ class XMLReport  {
             // remap the timezone from 0000 to 00:00 (starts at char 22)
             return dateStr.substring(0, 22) + ":" + dateStr.substring(22);
         }
-        
+
         /**
          * Convert string from JTR format to java.util.Date
          * @throws java.text.ParseException
@@ -459,7 +486,7 @@ class XMLReport  {
         static Date jtrToDate(String dateStr) throws ParseException {
             return TestResult.parseDate(dateStr);
         }
-        
+
         /**
          * Convert Status object to String
          */
@@ -470,7 +497,7 @@ class XMLReport  {
             if (st.isPassed()) return "PASSED";
             return "UNKNOWN";
         }
-        
+
         /**
          * Convert Status integer value to String
          */
@@ -481,17 +508,14 @@ class XMLReport  {
             if (st == Status.PASSED) return "PASSED";
             return "UNKNOWN";
         }
-        
+
     }
-    
+
     private static I18NResourceBundle i18n = I18NResourceBundle.getBundleForClass(XMLReport.class);
-    
+
     // The name of the root file for a set of report files.
     static final String REPORT_NAME = "report.xml";
-    
-    public static String[] getFilenamesUsed() {
-        return new String[] {REPORT_NAME};
-    }
 
+    private static final String ID = "xml";
 
 }
